#!/usr/bin/env python

# Capstone Python bindings, by Nguyen Anh Quynnh <aquynh@gmail.com>

from __future__ import print_function
from capstone import *

cs = Cs(CS_ARCH_EVM, 0)
cs.detail = True

for i in cs.disasm("\x60\x61\x55", 0x100):
    print("0x%x:\t%s\t%s" %(i.address, i.mnemonic, i.op_str))
    if i.pop > 0:
        print("\tPop:     %u" %i.pop)
    if i.push > 0:
        print("\tPush:    %u" %i.push)
    if i.fee > 0:
        print("\tGas fee: %u" %i.fee)
    if len(i.groups) > 0:
        print("\tThis instruction belongs to groups: ", end=''),
        for m in i.groups:
            print("%s " % i.group_name(m), end=''),
        print()



# For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [sysz_const.py]

SYSZ_CC_INVALID = 0
SYSZ_CC_O = 1
SYSZ_CC_H = 2
SYSZ_CC_NLE = 3
SYSZ_CC_L = 4
SYSZ_CC_NHE = 5
SYSZ_CC_LH = 6
SYSZ_CC_NE = 7
SYSZ_CC_E = 8
SYSZ_CC_NLH = 9
SYSZ_CC_HE = 10
SYSZ_CC_NL = 11
SYSZ_CC_LE = 12
SYSZ_CC_NH = 13
SYSZ_CC_NO = 14

SYSZ_OP_INVALID = 0
SYSZ_OP_REG = 1
SYSZ_OP_IMM = 2
SYSZ_OP_MEM = 3
SYSZ_OP_ACREG = 64

SYSZ_REG_INVALID = 0
SYSZ_REG_0 = 1
SYSZ_REG_1 = 2
SYSZ_REG_2 = 3
SYSZ_REG_3 = 4
SYSZ_REG_4 = 5
SYSZ_REG_5 = 6
SYSZ_REG_6 = 7
SYSZ_REG_7 = 8
SYSZ_REG_8 = 9
SYSZ_REG_9 = 10
SYSZ_REG_10 = 11
SYSZ_REG_11 = 12
SYSZ_REG_12 = 13
SYSZ_REG_13 = 14
SYSZ_REG_14 = 15
SYSZ_REG_15 = 16
SYSZ_REG_CC = 17
SYSZ_REG_F0 = 18
SYSZ_REG_F1 = 19
SYSZ_REG_F2 = 20
SYSZ_REG_F3 = 21
SYSZ_REG_F4 = 22
SYSZ_REG_F5 = 23
SYSZ_REG_F6 = 24
SYSZ_REG_F7 = 25
SYSZ_REG_F8 = 26
SYSZ_REG_F9 = 27
SYSZ_REG_F10 = 28
SYSZ_REG_F11 = 29
SYSZ_REG_F12 = 30
SYSZ_REG_F13 = 31
SYSZ_REG_F14 = 32
SYSZ_REG_F15 = 33
SYSZ_REG_R0L = 34
SYSZ_REG_ENDING = 35

SYSZ_INS_INVALID = 0
SYSZ_INS_A = 1
SYSZ_INS_ADB = 2
SYSZ_INS_ADBR = 3
SYSZ_INS_AEB = 4
SYSZ_INS_AEBR = 5
SYSZ_INS_AFI = 6
SYSZ_INS_AG = 7
SYSZ_INS_AGF = 8
SYSZ_INS_AGFI = 9
SYSZ_INS_AGFR = 10
SYSZ_INS_AGHI = 11
SYSZ_INS_AGHIK = 12
SYSZ_INS_AGR = 13
SYSZ_INS_AGRK = 14
SYSZ_INS_AGSI = 15
SYSZ_INS_AH = 16
SYSZ_INS_AHI = 17
SYSZ_INS_AHIK = 18
SYSZ_INS_AHY = 19
SYSZ_INS_AIH = 20
SYSZ_INS_AL = 21
SYSZ_INS_ALC = 22
SYSZ_INS_ALCG = 23
SYSZ_INS_ALCGR = 24
SYSZ_INS_ALCR = 25
SYSZ_INS_ALFI = 26
SYSZ_INS_ALG = 27
SYSZ_INS_ALGF = 28
SYSZ_INS_ALGFI = 29
SYSZ_INS_ALGFR = 30
SYSZ_INS_ALGHSIK = 31
SYSZ_INS_ALGR = 32
SYSZ_INS_ALGRK = 33
SYSZ_INS_ALHSIK = 34
SYSZ_INS_ALR = 35
SYSZ_INS_ALRK = 36
SYSZ_INS_ALY = 37
SYSZ_INS_AR = 38
SYSZ_INS_ARK = 39
SYSZ_INS_ASI = 40
SYSZ_INS_AXBR = 41
SYSZ_INS_AY = 42
SYSZ_INS_BCR = 43
SYSZ_INS_BRC = 44
SYSZ_INS_BRCL = 45
SYSZ_INS_CGIJ = 46
SYSZ_INS_CGRJ = 47
SYSZ_INS_CIJ = 48
SYSZ_INS_CLGIJ = 49
SYSZ_INS_CLGRJ = 50
SYSZ_INS_CLIJ = 51
SYSZ_INS_CLRJ = 52
SYSZ_INS_CRJ = 53
SYSZ_INS_BER = 54
SYSZ_INS_JE = 55
SYSZ_INS_JGE = 56
SYSZ_INS_LOCE = 57
SYSZ_INS_LOCGE = 58
SYSZ_INS_LOCGRE = 59
SYSZ_INS_LOCRE = 60
SYSZ_INS_STOCE = 61
SYSZ_INS_STOCGE = 62
SYSZ_INS_BHR = 63
SYSZ_INS_BHER = 64
SYSZ_INS_JHE = 65
SYSZ_INS_JGHE = 66
SYSZ_INS_LOCHE = 67
SYSZ_INS_LOCGHE = 68
SYSZ_INS_LOCGRHE = 69
SYSZ_INS_LOCRHE = 70
SYSZ_INS_STOCHE = 71
SYSZ_INS_STOCGHE = 72
SYSZ_INS_JH = 73
SYSZ_INS_JGH = 74
SYSZ_INS_LOCH = 75
SYSZ_INS_LOCGH = 76
SYSZ_INS_LOCGRH = 77
SYSZ_INS_LOCRH = 78
SYSZ_INS_STOCH = 79
SYSZ_INS_STOCGH = 80
SYSZ_INS_CGIJNLH = 81
SYSZ_INS_CGRJNLH = 82
SYSZ_INS_CIJNLH = 83
SYSZ_INS_CLGIJNLH = 84
SYSZ_INS_CLGRJNLH = 85
SYSZ_INS_CLIJNLH = 86
SYSZ_INS_CLRJNLH = 87
SYSZ_INS_CRJNLH = 88
SYSZ_INS_CGIJE = 89
SYSZ_INS_CGRJE = 90
SYSZ_INS_CIJE = 91
SYSZ_INS_CLGIJE = 92
SYSZ_INS_CLGRJE = 93
SYSZ_INS_CLIJE = 94
SYSZ_INS_CLRJE = 95
SYSZ_INS_CRJE = 96
SYSZ_INS_CGIJNLE = 97
SYSZ_INS_CGRJNLE = 98
SYSZ_INS_CIJNLE = 99
SYSZ_INS_CLGIJNLE = 100
SYSZ_INS_CLGRJNLE = 101
SYSZ_INS_CLIJNLE = 102
SYSZ_INS_CLRJNLE = 103
SYSZ_INS_CRJNLE = 104
SYSZ_INS_CGIJH = 105
SYSZ_INS_CGRJH = 106
SYSZ_INS_CIJH = 107
SYSZ_INS_CLGIJH = 108
SYSZ_INS_CLGRJH = 109
SYSZ_INS_CLIJH = 110
SYSZ_INS_CLRJH = 111
SYSZ_INS_CRJH = 112
SYSZ_INS_CGIJNL = 113
SYSZ_INS_CGRJNL = 114
SYSZ_INS_CIJNL = 115
SYSZ_INS_CLGIJNL = 116
SYSZ_INS_CLGRJNL = 117
SYSZ_INS_CLIJNL = 118
SYSZ_INS_CLRJNL = 119
SYSZ_INS_CRJNL = 120
SYSZ_INS_CGIJHE = 121
SYSZ_INS_CGRJHE = 122
SYSZ_INS_CIJHE = 123
SYSZ_INS_CLGIJHE = 124
SYSZ_INS_CLGRJHE = 125
SYSZ_INS_CLIJHE = 126
SYSZ_INS_CLRJHE = 127
SYSZ_INS_CRJHE = 128
SYSZ_INS_CGIJNHE = 129
SYSZ_INS_CGRJNHE = 130
SYSZ_INS_CIJNHE = 131
SYSZ_INS_CLGIJNHE = 132
SYSZ_INS_CLGRJNHE = 133
SYSZ_INS_CLIJNHE = 134
SYSZ_INS_CLRJNHE = 135
SYSZ_INS_CRJNHE = 136
SYSZ_INS_CGIJL = 137
SYSZ_INS_CGRJL = 138
SYSZ_INS_CIJL = 139
SYSZ_INS_CLGIJL = 140
SYSZ_INS_CLGRJL = 141
SYSZ_INS_CLIJL = 142
SYSZ_INS_CLRJL = 143
SYSZ_INS_CRJL = 144
SYSZ_INS_CGIJNH = 145
SYSZ_INS_CGRJNH = 146
SYSZ_INS_CIJNH = 147
SYSZ_INS_CLGIJNH = 148
SYSZ_INS_CLGRJNH = 149
SYSZ_INS_CLIJNH = 150
SYSZ_INS_CLRJNH = 151
SYSZ_INS_CRJNH = 152
SYSZ_INS_CGIJLE = 153
SYSZ_INS_CGRJLE = 154
SYSZ_INS_CIJLE = 155
SYSZ_INS_CLGIJLE = 156
SYSZ_INS_CLGRJLE = 157
SYSZ_INS_CLIJLE = 158
SYSZ_INS_CLRJLE = 159
SYSZ_INS_CRJLE = 160
SYSZ_INS_CGIJNE = 161
SYSZ_INS_CGRJNE = 162
SYSZ_INS_CIJNE = 163
SYSZ_INS_CLGIJNE = 164
SYSZ_INS_CLGRJNE = 165
SYSZ_INS_CLIJNE = 166
SYSZ_INS_CLRJNE = 167
SYSZ_INS_CRJNE = 168
SYSZ_INS_CGIJLH = 169
SYSZ_INS_CGRJLH = 170
SYSZ_INS_CIJLH = 171
SYSZ_INS_CLGIJLH = 172
SYSZ_INS_CLGRJLH = 173
SYSZ_INS_CLIJLH = 174
SYSZ_INS_CLRJLH = 175
SYSZ_INS_CRJLH = 176
SYSZ_INS_BLR = 177
SYSZ_INS_BLER = 178
SYSZ_INS_JLE = 179
SYSZ_INS_JGLE = 180
SYSZ_INS_LOCLE = 181
SYSZ_INS_LOCGLE = 182
SYSZ_INS_LOCGRLE = 183
SYSZ_INS_LOCRLE = 184
SYSZ_INS_STOCLE = 185
SYSZ_INS_STOCGLE = 186
SYSZ_INS_BLHR = 187
SYSZ_INS_JLH = 188
SYSZ_INS_JGLH = 189
SYSZ_INS_LOCLH = 190
SYSZ_INS_LOCGLH = 191
SYSZ_INS_LOCGRLH = 192
SYSZ_INS_LOCRLH = 193
SYSZ_INS_STOCLH = 194
SYSZ_INS_STOCGLH = 195
SYSZ_INS_JL = 196
SYSZ_INS_JGL = 197
SYSZ_INS_LOCL = 198
SYSZ_INS_LOCGL = 199
SYSZ_INS_LOCGRL = 200
SYSZ_INS_LOCRL = 201
SYSZ_INS_LOC = 202
SYSZ_INS_LOCG = 203
SYSZ_INS_LOCGR = 204
SYSZ_INS_LOCR = 205
SYSZ_INS_STOCL = 206
SYSZ_INS_STOCGL = 207
SYSZ_INS_BNER = 208
SYSZ_INS_JNE = 209
SYSZ_INS_JGNE = 210
SYSZ_INS_LOCNE = 211
SYSZ_INS_LOCGNE = 212
SYSZ_INS_LOCGRNE = 213
SYSZ_INS_LOCRNE = 214
SYSZ_INS_STOCNE = 215
SYSZ_INS_STOCGNE = 216
SYSZ_INS_BNHR = 217
SYSZ_INS_BNHER = 218
SYSZ_INS_JNHE = 219
SYSZ_INS_JGNHE = 220
SYSZ_INS_LOCNHE = 221
SYSZ_INS_LOCGNHE = 222
SYSZ_INS_LOCGRNHE = 223
SYSZ_INS_LOCRNHE = 224
SYSZ_INS_STOCNHE = 225
SYSZ_INS_STOCGNHE = 226
SYSZ_INS_JNH = 227
SYSZ_INS_JGNH = 228
SYSZ_INS_LOCNH = 229
SYSZ_INS_LOCGNH = 230
SYSZ_INS_LOCGRNH = 231
SYSZ_INS_LOCRNH = 232
SYSZ_INS_STOCNH = 233
SYSZ_INS_STOCGNH = 234
SYSZ_INS_BNLR = 235
SYSZ_INS_BNLER = 236
SYSZ_INS_JNLE = 237
SYSZ_INS_JGNLE = 238
SYSZ_INS_LOCNLE = 239
SYSZ_INS_LOCGNLE = 240
SYSZ_INS_LOCGRNLE = 241
SYSZ_INS_LOCRNLE = 242
SYSZ_INS_STOCNLE = 243
SYSZ_INS_STOCGNLE = 244
SYSZ_INS_BNLHR = 245
SYSZ_INS_JNLH = 246
SYSZ_INS_JGNLH = 247
SYSZ_INS_LOCNLH = 248
SYSZ_INS_LOCGNLH = 249
SYSZ_INS_LOCGRNLH = 250
SYSZ_INS_LOCRNLH = 251
SYSZ_INS_STOCNLH = 252
SYSZ_INS_STOCGNLH = 253
SYSZ_INS_JNL = 254
SYSZ_INS_JGNL = 255
SYSZ_INS_LOCNL = 256
SYSZ_INS_LOCGNL = 257
SYSZ_INS_LOCGRNL = 258
SYSZ_INS_LOCRNL = 259
SYSZ_INS_STOCNL = 260
SYSZ_INS_STOCGNL = 261
SYSZ_INS_BNOR = 262
SYSZ_INS_JNO = 263
SYSZ_INS_JGNO = 264
SYSZ_INS_LOCNO = 265
SYSZ_INS_LOCGNO = 266
SYSZ_INS_LOCGRNO = 267
SYSZ_INS_LOCRNO = 268
SYSZ_INS_STOCNO = 269
SYSZ_INS_STOCGNO = 270
SYSZ_INS_BOR = 271
SYSZ_INS_JO = 272
SYSZ_INS_JGO = 273
SYSZ_INS_LOCO = 274
SYSZ_INS_LOCGO = 275
SYSZ_INS_LOCGRO = 276
SYSZ_INS_LOCRO = 277
SYSZ_INS_STOCO = 278
SYSZ_INS_STOCGO = 279
SYSZ_INS_STOC = 280
SYSZ_INS_STOCG = 281
SYSZ_INS_BASR = 282
SYSZ_INS_BR = 283
SYSZ_INS_BRAS = 284
SYSZ_INS_BRASL = 285
SYSZ_INS_J = 286
SYSZ_INS_JG = 287
SYSZ_INS_BRCT = 288
SYSZ_INS_BRCTG = 289
SYSZ_INS_C = 290
SYSZ_INS_CDB = 291
SYSZ_INS_CDBR = 292
SYSZ_INS_CDFBR = 293
SYSZ_INS_CDGBR = 294
SYSZ_INS_CDLFBR = 295
SYSZ_INS_CDLGBR = 296
SYSZ_INS_CEB = 297
SYSZ_INS_CEBR = 298
SYSZ_INS_CEFBR = 299
SYSZ_INS_CEGBR = 300
SYSZ_INS_CELFBR = 301
SYSZ_INS_CELGBR = 302
SYSZ_INS_CFDBR = 303
SYSZ_INS_CFEBR = 304
SYSZ_INS_CFI = 305
SYSZ_INS_CFXBR = 306
SYSZ_INS_CG = 307
SYSZ_INS_CGDBR = 308
SYSZ_INS_CGEBR = 309
SYSZ_INS_CGF = 310
SYSZ_INS_CGFI = 311
SYSZ_INS_CGFR = 312
SYSZ_INS_CGFRL = 313
SYSZ_INS_CGH = 314
SYSZ_INS_CGHI = 315
SYSZ_INS_CGHRL = 316
SYSZ_INS_CGHSI = 317
SYSZ_INS_CGR = 318
SYSZ_INS_CGRL = 319
SYSZ_INS_CGXBR = 320
SYSZ_INS_CH = 321
SYSZ_INS_CHF = 322
SYSZ_INS_CHHSI = 323
SYSZ_INS_CHI = 324
SYSZ_INS_CHRL = 325
SYSZ_INS_CHSI = 326
SYSZ_INS_CHY = 327
SYSZ_INS_CIH = 328
SYSZ_INS_CL = 329
SYSZ_INS_CLC = 330
SYSZ_INS_CLFDBR = 331
SYSZ_INS_CLFEBR = 332
SYSZ_INS_CLFHSI = 333
SYSZ_INS_CLFI = 334
SYSZ_INS_CLFXBR = 335
SYSZ_INS_CLG = 336
SYSZ_INS_CLGDBR = 337
SYSZ_INS_CLGEBR = 338
SYSZ_INS_CLGF = 339
SYSZ_INS_CLGFI = 340
SYSZ_INS_CLGFR = 341
SYSZ_INS_CLGFRL = 342
SYSZ_INS_CLGHRL = 343
SYSZ_INS_CLGHSI = 344
SYSZ_INS_CLGR = 345
SYSZ_INS_CLGRL = 346
SYSZ_INS_CLGXBR = 347
SYSZ_INS_CLHF = 348
SYSZ_INS_CLHHSI = 349
SYSZ_INS_CLHRL = 350
SYSZ_INS_CLI = 351
SYSZ_INS_CLIH = 352
SYSZ_INS_CLIY = 353
SYSZ_INS_CLR = 354
SYSZ_INS_CLRL = 355
SYSZ_INS_CLST = 356
SYSZ_INS_CLY = 357
SYSZ_INS_CPSDR = 358
SYSZ_INS_CR = 359
SYSZ_INS_CRL = 360
SYSZ_INS_CS = 361
SYSZ_INS_CSG = 362
SYSZ_INS_CSY = 363
SYSZ_INS_CXBR = 364
SYSZ_INS_CXFBR = 365
SYSZ_INS_CXGBR = 366
SYSZ_INS_CXLFBR = 367
SYSZ_INS_CXLGBR = 368
SYSZ_INS_CY = 369
SYSZ_INS_DDB = 370
SYSZ_INS_DDBR = 371
SYSZ_INS_DEB = 372
SYSZ_INS_DEBR = 373
SYSZ_INS_DL = 374
SYSZ_INS_DLG = 375
SYSZ_INS_DLGR = 376
SYSZ_INS_DLR = 377
SYSZ_INS_DSG = 378
SYSZ_INS_DSGF = 379
SYSZ_INS_DSGFR = 380
SYSZ_INS_DSGR = 381
SYSZ_INS_DXBR = 382
SYSZ_INS_EAR = 383
SYSZ_INS_FIDBR = 384
SYSZ_INS_FIDBRA = 385
SYSZ_INS_FIEBR = 386
SYSZ_INS_FIEBRA = 387
SYSZ_INS_FIXBR = 388
SYSZ_INS_FIXBRA = 389
SYSZ_INS_FLOGR = 390
SYSZ_INS_IC = 391
SYSZ_INS_ICY = 392
SYSZ_INS_IIHF = 393
SYSZ_INS_IIHH = 394
SYSZ_INS_IIHL = 395
SYSZ_INS_IILF = 396
SYSZ_INS_IILH = 397
SYSZ_INS_IILL = 398
SYSZ_INS_IPM = 399
SYSZ_INS_L = 400
SYSZ_INS_LA = 401
SYSZ_INS_LAA = 402
SYSZ_INS_LAAG = 403
SYSZ_INS_LAAL = 404
SYSZ_INS_LAALG = 405
SYSZ_INS_LAN = 406
SYSZ_INS_LANG = 407
SYSZ_INS_LAO = 408
SYSZ_INS_LAOG = 409
SYSZ_INS_LARL = 410
SYSZ_INS_LAX = 411
SYSZ_INS_LAXG = 412
SYSZ_INS_LAY = 413
SYSZ_INS_LB = 414
SYSZ_INS_LBH = 415
SYSZ_INS_LBR = 416
SYSZ_INS_LCDBR = 417
SYSZ_INS_LCEBR = 418
SYSZ_INS_LCGFR = 419
SYSZ_INS_LCGR = 420
SYSZ_INS_LCR = 421
SYSZ_INS_LCXBR = 422
SYSZ_INS_LD = 423
SYSZ_INS_LDEB = 424
SYSZ_INS_LDEBR = 425
SYSZ_INS_LDGR = 426
SYSZ_INS_LDR = 427
SYSZ_INS_LDXBR = 428
SYSZ_INS_LDXBRA = 429
SYSZ_INS_LDY = 430
SYSZ_INS_LE = 431
SYSZ_INS_LEDBR = 432
SYSZ_INS_LEDBRA = 433
SYSZ_INS_LER = 434
SYSZ_INS_LEXBR = 435
SYSZ_INS_LEXBRA = 436
SYSZ_INS_LEY = 437
SYSZ_INS_LFH = 438
SYSZ_INS_LG = 439
SYSZ_INS_LGB = 440
SYSZ_INS_LGBR = 441
SYSZ_INS_LGDR = 442
SYSZ_INS_LGF = 443
SYSZ_INS_LGFI = 444
SYSZ_INS_LGFR = 445
SYSZ_INS_LGFRL = 446
SYSZ_INS_LGH = 447
SYSZ_INS_LGHI = 448
SYSZ_INS_LGHR = 449
SYSZ_INS_LGHRL = 450
SYSZ_INS_LGR = 451
SYSZ_INS_LGRL = 452
SYSZ_INS_LH = 453
SYSZ_INS_LHH = 454
SYSZ_INS_LHI = 455
SYSZ_INS_LHR = 456
SYSZ_INS_LHRL = 457
SYSZ_INS_LHY = 458
SYSZ_INS_LLC = 459
SYSZ_INS_LLCH = 460
SYSZ_INS_LLCR = 461
SYSZ_INS_LLGC = 462
SYSZ_INS_LLGCR = 463
SYSZ_INS_LLGF = 464
SYSZ_INS_LLGFR = 465
SYSZ_INS_LLGFRL = 466
SYSZ_INS_LLGH = 467
SYSZ_INS_LLGHR = 468
SYSZ_INS_LLGHRL = 469
SYSZ_INS_LLH = 470
SYSZ_INS_LLHH = 471
SYSZ_INS_LLHR = 472
SYSZ_INS_LLHRL = 473
SYSZ_INS_LLIHF = 474
SYSZ_INS_LLIHH = 475
SYSZ_INS_LLIHL = 476
SYSZ_INS_LLILF = 477
SYSZ_INS_LLILH = 478
SYSZ_INS_LLILL = 479
SYSZ_INS_LMG = 480
SYSZ_INS_LNDBR = 481
SYSZ_INS_LNEBR = 482
SYSZ_INS_LNGFR = 483
SYSZ_INS_LNGR = 484
SYSZ_INS_LNR = 485
SYSZ_INS_LNXBR = 486
SYSZ_INS_LPDBR = 487
SYSZ_INS_LPEBR = 488
SYSZ_INS_LPGFR = 489
SYSZ_INS_LPGR = 490
SYSZ_INS_LPR = 491
SYSZ_INS_LPXBR = 492
SYSZ_INS_LR = 493
SYSZ_INS_LRL = 494
SYSZ_INS_LRV = 495
SYSZ_INS_LRVG = 496
SYSZ_INS_LRVGR = 497
SYSZ_INS_LRVR = 498
SYSZ_INS_LT = 499
SYSZ_INS_LTDBR = 500
SYSZ_INS_LTEBR = 501
SYSZ_INS_LTG = 502
SYSZ_INS_LTGF = 503
SYSZ_INS_LTGFR = 504
SYSZ_INS_LTGR = 505
SYSZ_INS_LTR = 506
SYSZ_INS_LTXBR = 507
SYSZ_INS_LXDB = 508
SYSZ_INS_LXDBR = 509
SYSZ_INS_LXEB = 510
SYSZ_INS_LXEBR = 511
SYSZ_INS_LXR = 512
SYSZ_INS_LY = 513
SYSZ_INS_LZDR = 514
SYSZ_INS_LZER = 515
SYSZ_INS_LZXR = 516
SYSZ_INS_MADB = 517
SYSZ_INS_MADBR = 518
SYSZ_INS_MAEB = 519
SYSZ_INS_MAEBR = 520
SYSZ_INS_MDB = 521
SYSZ_INS_MDBR = 522
SYSZ_INS_MDEB = 523
SYSZ_INS_MDEBR = 524
SYSZ_INS_MEEB = 525
SYSZ_INS_MEEBR = 526
SYSZ_INS_MGHI = 527
SYSZ_INS_MH = 528
SYSZ_INS_MHI = 529
SYSZ_INS_MHY = 530
SYSZ_INS_MLG = 531
SYSZ_INS_MLGR = 532
SYSZ_INS_MS = 533
SYSZ_INS_MSDB = 534
SYSZ_INS_MSDBR = 535
SYSZ_INS_MSEB = 536
SYSZ_INS_MSEBR = 537
SYSZ_INS_MSFI = 538
SYSZ_INS_MSG = 539
SYSZ_INS_MSGF = 540
SYSZ_INS_MSGFI = 541
SYSZ_INS_MSGFR = 542
SYSZ_INS_MSGR = 543
SYSZ_INS_MSR = 544
SYSZ_INS_MSY = 545
SYSZ_INS_MVC = 546
SYSZ_INS_MVGHI = 547
SYSZ_INS_MVHHI = 548
SYSZ_INS_MVHI = 549
SYSZ_INS_MVI = 550
SYSZ_INS_MVIY = 551
SYSZ_INS_MVST = 552
SYSZ_INS_MXBR = 553
SYSZ_INS_MXDB = 554
SYSZ_INS_MXDBR = 555
SYSZ_INS_N = 556
SYSZ_INS_NC = 557
SYSZ_INS_NG = 558
SYSZ_INS_NGR = 559
SYSZ_INS_NGRK = 560
SYSZ_INS_NI = 561
SYSZ_INS_NIHF = 562
SYSZ_INS_NIHH = 563
SYSZ_INS_NIHL = 564
SYSZ_INS_NILF = 565
SYSZ_INS_NILH = 566
SYSZ_INS_NILL = 567
SYSZ_INS_NIY = 568
SYSZ_INS_NR = 569
SYSZ_INS_NRK = 570
SYSZ_INS_NY = 571
SYSZ_INS_O = 572
SYSZ_INS_OC = 573
SYSZ_INS_OG = 574
SYSZ_INS_OGR = 575
SYSZ_INS_OGRK = 576
SYSZ_INS_OI = 577
SYSZ_INS_OIHF = 578
SYSZ_INS_OIHH = 579
SYSZ_INS_OIHL = 580
SYSZ_INS_OILF = 581
SYSZ_INS_OILH = 582
SYSZ_INS_OILL = 583
SYSZ_INS_OIY = 584
SYSZ_INS_OR = 585
SYSZ_INS_ORK = 586
SYSZ_INS_OY = 587
SYSZ_INS_PFD = 588
SYSZ_INS_PFDRL = 589
SYSZ_INS_RISBG = 590
SYSZ_INS_RISBHG = 591
SYSZ_INS_RISBLG = 592
SYSZ_INS_RLL = 593
SYSZ_INS_RLLG = 594
SYSZ_INS_RNSBG = 595
SYSZ_INS_ROSBG = 596
SYSZ_INS_RXSBG = 597
SYSZ_INS_S = 598
SYSZ_INS_SDB = 599
SYSZ_INS_SDBR = 600
SYSZ_INS_SEB = 601
SYSZ_INS_SEBR = 602
SYSZ_INS_SG = 603
SYSZ_INS_SGF = 604
SYSZ_INS_SGFR = 605
SYSZ_INS_SGR = 606
SYSZ_INS_SGRK = 607
SYSZ_INS_SH = 608
SYSZ_INS_SHY = 609
SYSZ_INS_SL = 610
SYSZ_INS_SLB = 611
SYSZ_INS_SLBG = 612
SYSZ_INS_SLBR = 613
SYSZ_INS_SLFI = 614
SYSZ_INS_SLG = 615
SYSZ_INS_SLBGR = 616
SYSZ_INS_SLGF = 617
SYSZ_INS_SLGFI = 618
SYSZ_INS_SLGFR = 619
SYSZ_INS_SLGR = 620
SYSZ_INS_SLGRK = 621
SYSZ_INS_SLL = 622
SYSZ_INS_SLLG = 623
SYSZ_INS_SLLK = 624
SYSZ_INS_SLR = 625
SYSZ_INS_SLRK = 626
SYSZ_INS_SLY = 627
SYSZ_INS_SQDB = 628
SYSZ_INS_SQDBR = 629
SYSZ_INS_SQEB = 630
SYSZ_INS_SQEBR = 631
SYSZ_INS_SQXBR = 632
SYSZ_INS_SR = 633
SYSZ_INS_SRA = 634
SYSZ_INS_SRAG = 635
SYSZ_INS_SRAK = 636
SYSZ_INS_SRK = 637
SYSZ_INS_SRL = 638
SYSZ_INS_SRLG = 639
SYSZ_INS_SRLK = 640
SYSZ_INS_SRST = 641
SYSZ_INS_ST = 642
SYSZ_INS_STC = 643
SYSZ_INS_STCH = 644
SYSZ_INS_STCY = 645
SYSZ_INS_STD = 646
SYSZ_INS_STDY = 647
SYSZ_INS_STE = 648
SYSZ_INS_STEY = 649
SYSZ_INS_STFH = 650
SYSZ_INS_STG = 651
SYSZ_INS_STGRL = 652
SYSZ_INS_STH = 653
SYSZ_INS_STHH = 654
SYSZ_INS_STHRL = 655
SYSZ_INS_STHY = 656
SYSZ_INS_STMG = 657
SYSZ_INS_STRL = 658
SYSZ_INS_STRV = 659
SYSZ_INS_STRVG = 660
SYSZ_INS_STY = 661
SYSZ_INS_SXBR = 662
SYSZ_INS_SY = 663
SYSZ_INS_TM = 664
SYSZ_INS_TMHH = 665
SYSZ_INS_TMHL = 666
SYSZ_INS_TMLH = 667
SYSZ_INS_TMLL = 668
SYSZ_INS_TMY = 669
SYSZ_INS_X = 670
SYSZ_INS_XC = 671
SYSZ_INS_XG = 672
SYSZ_INS_XGR = 673
SYSZ_INS_XGRK = 674
SYSZ_INS_XI = 675
SYSZ_INS_XIHF = 676
SYSZ_INS_XILF = 677
SYSZ_INS_XIY = 678
SYSZ_INS_XR = 679
SYSZ_INS_XRK = 680
SYSZ_INS_XY = 681
SYSZ_INS_ENDING = 682

SYSZ_GRP_INVALID = 0
SYSZ_GRP_JUMP = 1
SYSZ_GRP_DISTINCTOPS = 128
SYSZ_GRP_FPEXTENSION = 129
SYSZ_GRP_HIGHWORD = 130
SYSZ_GRP_INTERLOCKEDACCESS1 = 131
SYSZ_GRP_LOADSTOREONCOND = 132
SYSZ_GRP_ENDING = 133



import os
import sys
import shutil

from distutils import log
from distutils.core import setup
from distutils.extension import Extension
from distutils.command.build import build
from Cython.Distutils import build_ext

SYSTEM = sys.platform
VERSION = '4.0.0'

# adapted from commit e504b81 of Nguyen Tan Cong
# Reference: https://docs.python.org/2/library/platform.html#cross-platform
IS_64BITS = sys.maxsize > 2**32

# are we building from the repository or from a source distribution?
ROOT_DIR = os.path.dirname(os.path.realpath(__file__))
LIBS_DIR = os.path.join(ROOT_DIR, 'pyx', 'lib')
HEADERS_DIR = os.path.join(ROOT_DIR, 'pyx', 'include')
SRC_DIR = os.path.join(ROOT_DIR, 'src')
BUILD_DIR = SRC_DIR if os.path.exists(SRC_DIR) else os.path.join(ROOT_DIR, '../..')
PYPACKAGE_DIR = os.path.join(ROOT_DIR, 'capstone')
CYPACKAGE_DIR = os.path.join(ROOT_DIR, 'pyx')

if SYSTEM == 'darwin':
    VERSIONED_LIBRARY_FILE = "libcapstone.4.dylib"
    LIBRARY_FILE = "libcapstone.dylib"
    STATIC_LIBRARY_FILE = 'libcapstone.a'
elif SYSTEM in ('win32', 'cygwin'):
    VERSIONED_LIBRARY_FILE = "capstone.dll"
    LIBRARY_FILE = "capstone.dll"
    STATIC_LIBRARY_FILE = None
else:
    VERSIONED_LIBRARY_FILE = "libcapstone.so.4"
    LIBRARY_FILE = "libcapstone.so"
    STATIC_LIBRARY_FILE = 'libcapstone.a'

compile_args = ['-O3', '-fomit-frame-pointer', '-I' + HEADERS_DIR]
link_args = ['-L' + LIBS_DIR]

ext_module_names = ['arm', 'arm_const', 'arm64', 'arm64_const', 'm68k', 'm68k_const', 'm680x', 'm680x_const', 'mips', 'mips_const', 'ppc', 'ppc_const', 'x86', 'x86_const', 'sparc', 'sparc_const', 'systemz', 'sysz_const', 'xcore', 'xcore_const', 'tms320c64x', 'tms320c64x_const', 'evm', 'evm_const' ]

ext_modules = [Extension("capstone.ccapstone",
                         ["pyx/ccapstone.pyx"],
                         libraries=["capstone"],
                         extra_compile_args=compile_args,
                         extra_link_args=link_args)]
ext_modules += [Extension("capstone.%s" % name,
                          ["pyx/%s.pyx" % name],
                          extra_compile_args=compile_args,
                          extra_link_args=link_args)
                for name in ext_module_names]

def clean_bins():
    shutil.rmtree(LIBS_DIR, ignore_errors=True)
    shutil.rmtree(HEADERS_DIR, ignore_errors=True)

def copy_pysources():
    for fname in os.listdir(PYPACKAGE_DIR):
        if not fname.endswith('.py'):
            continue

        if fname == '__init__.py':
            shutil.copy(os.path.join(PYPACKAGE_DIR, fname), os.path.join(CYPACKAGE_DIR, fname))
        else:
            shutil.copy(os.path.join(PYPACKAGE_DIR, fname), os.path.join(CYPACKAGE_DIR, fname + 'x'))

def build_libraries():
    """
    Prepare the capstone directory for a binary distribution or installation.
    Builds shared libraries and copies header files.

    Will use a src/ dir if one exists in the current directory, otherwise assumes it's in the repo
    """
    cwd = os.getcwd()
    clean_bins()
    os.mkdir(HEADERS_DIR)
    os.mkdir(LIBS_DIR)

    # copy public headers
    shutil.copytree(os.path.join(BUILD_DIR, 'include', 'capstone'), os.path.join(HEADERS_DIR, 'capstone'))

    os.chdir(BUILD_DIR)

    # platform description refers at https://docs.python.org/2/library/sys.html#sys.platform
    if SYSTEM == "win32":
        # Windows build: this process requires few things:
        #    - CMake + MSVC installed
        #    - Run this command in an environment setup for MSVC
        if not os.path.exists("build"): os.mkdir("build")
        os.chdir("build")
        # Do not build tests & static library
        os.system('cmake -DCMAKE_BUILD_TYPE=RELEASE -DCAPSTONE_BUILD_TESTS=0 -DCAPSTONE_BUILD_STATIC=0 -G "NMake Makefiles" ..')
        os.system("nmake")
    else:   # Unix incl. cygwin
        os.system("CAPSTONE_BUILD_CORE_ONLY=yes bash ./make.sh")

    shutil.copy(VERSIONED_LIBRARY_FILE, os.path.join(LIBS_DIR, LIBRARY_FILE))
    if STATIC_LIBRARY_FILE: shutil.copy(STATIC_LIBRARY_FILE, LIBS_DIR)
    os.chdir(cwd)


class custom_build(build):
    def run(self):
        log.info('Copying python sources')
        copy_pysources()
        log.info('Building C extensions')
        build_libraries()
        return build.run(self)

# clean package directory first
#import os.path, shutil, sys
#for f in sys.path:
#    if f.endswith('packages'):
#        pkgdir = os.path.join(f, 'capstone')
#        #print(pkgdir)
#        try:
#            shutil.rmtree(pkgdir)
#        except:
#            pass

setup(
    provides     = ['capstone'],
    package_dir  = {'capstone' : 'pyx'},
    packages     = ['capstone'],
    name         = 'capstone',
    version      = VERSION,
    cmdclass     = {'build_ext': build_ext, 'build': custom_build},
    ext_modules  = ext_modules,
    author       = 'Nguyen Anh Quynh',
    author_email = 'aquynh@gmail.com',
    description  = 'Capstone disassembly engine',
    url          = 'http://www.capstone-engine.org',
    classifiers  = [
                'License :: OSI Approved :: BSD License',
                'Programming Language :: Python :: 2',
                ],
    include_package_data=True,
    package_data={
        "capstone": ["lib/*", "include/capstone/*"],
    }
)



# For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [arm64_const.py]

ARM64_SFT_INVALID = 0
ARM64_SFT_LSL = 1
ARM64_SFT_MSL = 2
ARM64_SFT_LSR = 3
ARM64_SFT_ASR = 4
ARM64_SFT_ROR = 5

ARM64_EXT_INVALID = 0
ARM64_EXT_UXTB = 1
ARM64_EXT_UXTH = 2
ARM64_EXT_UXTW = 3
ARM64_EXT_UXTX = 4
ARM64_EXT_SXTB = 5
ARM64_EXT_SXTH = 6
ARM64_EXT_SXTW = 7
ARM64_EXT_SXTX = 8

ARM64_CC_INVALID = 0
ARM64_CC_EQ = 1
ARM64_CC_NE = 2
ARM64_CC_HS = 3
ARM64_CC_LO = 4
ARM64_CC_MI = 5
ARM64_CC_PL = 6
ARM64_CC_VS = 7
ARM64_CC_VC = 8
ARM64_CC_HI = 9
ARM64_CC_LS = 10
ARM64_CC_GE = 11
ARM64_CC_LT = 12
ARM64_CC_GT = 13
ARM64_CC_LE = 14
ARM64_CC_AL = 15
ARM64_CC_NV = 16

ARM64_SYSREG_INVALID = 0
ARM64_SYSREG_MDCCSR_EL0 = 0x9808
ARM64_SYSREG_DBGDTRRX_EL0 = 0x9828
ARM64_SYSREG_MDRAR_EL1 = 0x8080
ARM64_SYSREG_OSLSR_EL1 = 0x808c
ARM64_SYSREG_DBGAUTHSTATUS_EL1 = 0x83f6
ARM64_SYSREG_PMCEID0_EL0 = 0xdce6
ARM64_SYSREG_PMCEID1_EL0 = 0xdce7
ARM64_SYSREG_MIDR_EL1 = 0xc000
ARM64_SYSREG_CCSIDR_EL1 = 0xc800
ARM64_SYSREG_CLIDR_EL1 = 0xc801
ARM64_SYSREG_CTR_EL0 = 0xd801
ARM64_SYSREG_MPIDR_EL1 = 0xc005
ARM64_SYSREG_REVIDR_EL1 = 0xc006
ARM64_SYSREG_AIDR_EL1 = 0xc807
ARM64_SYSREG_DCZID_EL0 = 0xd807
ARM64_SYSREG_ID_PFR0_EL1 = 0xc008
ARM64_SYSREG_ID_PFR1_EL1 = 0xc009
ARM64_SYSREG_ID_DFR0_EL1 = 0xc00a
ARM64_SYSREG_ID_AFR0_EL1 = 0xc00b
ARM64_SYSREG_ID_MMFR0_EL1 = 0xc00c
ARM64_SYSREG_ID_MMFR1_EL1 = 0xc00d
ARM64_SYSREG_ID_MMFR2_EL1 = 0xc00e
ARM64_SYSREG_ID_MMFR3_EL1 = 0xc00f
ARM64_SYSREG_ID_ISAR0_EL1 = 0xc010
ARM64_SYSREG_ID_ISAR1_EL1 = 0xc011
ARM64_SYSREG_ID_ISAR2_EL1 = 0xc012
ARM64_SYSREG_ID_ISAR3_EL1 = 0xc013
ARM64_SYSREG_ID_ISAR4_EL1 = 0xc014
ARM64_SYSREG_ID_ISAR5_EL1 = 0xc015
ARM64_SYSREG_ID_A64PFR0_EL1 = 0xc020
ARM64_SYSREG_ID_A64PFR1_EL1 = 0xc021
ARM64_SYSREG_ID_A64DFR0_EL1 = 0xc028
ARM64_SYSREG_ID_A64DFR1_EL1 = 0xc029
ARM64_SYSREG_ID_A64AFR0_EL1 = 0xc02c
ARM64_SYSREG_ID_A64AFR1_EL1 = 0xc02d
ARM64_SYSREG_ID_A64ISAR0_EL1 = 0xc030
ARM64_SYSREG_ID_A64ISAR1_EL1 = 0xc031
ARM64_SYSREG_ID_A64MMFR0_EL1 = 0xc038
ARM64_SYSREG_ID_A64MMFR1_EL1 = 0xc039
ARM64_SYSREG_MVFR0_EL1 = 0xc018
ARM64_SYSREG_MVFR1_EL1 = 0xc019
ARM64_SYSREG_MVFR2_EL1 = 0xc01a
ARM64_SYSREG_RVBAR_EL1 = 0xc601
ARM64_SYSREG_RVBAR_EL2 = 0xe601
ARM64_SYSREG_RVBAR_EL3 = 0xf601
ARM64_SYSREG_ISR_EL1 = 0xc608
ARM64_SYSREG_CNTPCT_EL0 = 0xdf01
ARM64_SYSREG_CNTVCT_EL0 = 0xdf02
ARM64_SYSREG_TRCSTATR = 0x8818
ARM64_SYSREG_TRCIDR8 = 0x8806
ARM64_SYSREG_TRCIDR9 = 0x880e
ARM64_SYSREG_TRCIDR10 = 0x8816
ARM64_SYSREG_TRCIDR11 = 0x881e
ARM64_SYSREG_TRCIDR12 = 0x8826
ARM64_SYSREG_TRCIDR13 = 0x882e
ARM64_SYSREG_TRCIDR0 = 0x8847
ARM64_SYSREG_TRCIDR1 = 0x884f
ARM64_SYSREG_TRCIDR2 = 0x8857
ARM64_SYSREG_TRCIDR3 = 0x885f
ARM64_SYSREG_TRCIDR4 = 0x8867
ARM64_SYSREG_TRCIDR5 = 0x886f
ARM64_SYSREG_TRCIDR6 = 0x8877
ARM64_SYSREG_TRCIDR7 = 0x887f
ARM64_SYSREG_TRCOSLSR = 0x888c
ARM64_SYSREG_TRCPDSR = 0x88ac
ARM64_SYSREG_TRCDEVAFF0 = 0x8bd6
ARM64_SYSREG_TRCDEVAFF1 = 0x8bde
ARM64_SYSREG_TRCLSR = 0x8bee
ARM64_SYSREG_TRCAUTHSTATUS = 0x8bf6
ARM64_SYSREG_TRCDEVARCH = 0x8bfe
ARM64_SYSREG_TRCDEVID = 0x8b97
ARM64_SYSREG_TRCDEVTYPE = 0x8b9f
ARM64_SYSREG_TRCPIDR4 = 0x8ba7
ARM64_SYSREG_TRCPIDR5 = 0x8baf
ARM64_SYSREG_TRCPIDR6 = 0x8bb7
ARM64_SYSREG_TRCPIDR7 = 0x8bbf
ARM64_SYSREG_TRCPIDR0 = 0x8bc7
ARM64_SYSREG_TRCPIDR1 = 0x8bcf
ARM64_SYSREG_TRCPIDR2 = 0x8bd7
ARM64_SYSREG_TRCPIDR3 = 0x8bdf
ARM64_SYSREG_TRCCIDR0 = 0x8be7
ARM64_SYSREG_TRCCIDR1 = 0x8bef
ARM64_SYSREG_TRCCIDR2 = 0x8bf7
ARM64_SYSREG_TRCCIDR3 = 0x8bff
ARM64_SYSREG_ICC_IAR1_EL1 = 0xc660
ARM64_SYSREG_ICC_IAR0_EL1 = 0xc640
ARM64_SYSREG_ICC_HPPIR1_EL1 = 0xc662
ARM64_SYSREG_ICC_HPPIR0_EL1 = 0xc642
ARM64_SYSREG_ICC_RPR_EL1 = 0xc65b
ARM64_SYSREG_ICH_VTR_EL2 = 0xe659
ARM64_SYSREG_ICH_EISR_EL2 = 0xe65b
ARM64_SYSREG_ICH_ELSR_EL2 = 0xe65d
ARM64_SYSREG_DBGDTRTX_EL0 = 0x9828
ARM64_SYSREG_OSLAR_EL1 = 0x8084
ARM64_SYSREG_PMSWINC_EL0 = 0xdce4
ARM64_SYSREG_TRCOSLAR = 0x8884
ARM64_SYSREG_TRCLAR = 0x8be6
ARM64_SYSREG_ICC_EOIR1_EL1 = 0xc661
ARM64_SYSREG_ICC_EOIR0_EL1 = 0xc641
ARM64_SYSREG_ICC_DIR_EL1 = 0xc659
ARM64_SYSREG_ICC_SGI1R_EL1 = 0xc65d
ARM64_SYSREG_ICC_ASGI1R_EL1 = 0xc65e
ARM64_SYSREG_ICC_SGI0R_EL1 = 0xc65f

ARM64_PSTATE_INVALID = 0
ARM64_PSTATE_SPSEL = 0x05
ARM64_PSTATE_DAIFSET = 0x1e
ARM64_PSTATE_DAIFCLR = 0x1f

ARM64_VAS_INVALID = 0
ARM64_VAS_8B = 1
ARM64_VAS_16B = 2
ARM64_VAS_4H = 3
ARM64_VAS_8H = 4
ARM64_VAS_2S = 5
ARM64_VAS_4S = 6
ARM64_VAS_1D = 7
ARM64_VAS_2D = 8
ARM64_VAS_1Q = 9

ARM64_VESS_INVALID = 0
ARM64_VESS_B = 1
ARM64_VESS_H = 2
ARM64_VESS_S = 3
ARM64_VESS_D = 4

ARM64_BARRIER_INVALID = 0
ARM64_BARRIER_OSHLD = 0x1
ARM64_BARRIER_OSHST = 0x2
ARM64_BARRIER_OSH = 0x3
ARM64_BARRIER_NSHLD = 0x5
ARM64_BARRIER_NSHST = 0x6
ARM64_BARRIER_NSH = 0x7
ARM64_BARRIER_ISHLD = 0x9
ARM64_BARRIER_ISHST = 0xa
ARM64_BARRIER_ISH = 0xb
ARM64_BARRIER_LD = 0xd
ARM64_BARRIER_ST = 0xe
ARM64_BARRIER_SY = 0xf

ARM64_OP_INVALID = 0
ARM64_OP_REG = 1
ARM64_OP_IMM = 2
ARM64_OP_MEM = 3
ARM64_OP_FP = 4
ARM64_OP_CIMM = 64
ARM64_OP_REG_MRS = 65
ARM64_OP_REG_MSR = 66
ARM64_OP_PSTATE = 67
ARM64_OP_SYS = 68
ARM64_OP_PREFETCH = 69
ARM64_OP_BARRIER = 70

ARM64_TLBI_INVALID = 0
ARM64_TLBI_VMALLE1IS = 1
ARM64_TLBI_VAE1IS = 2
ARM64_TLBI_ASIDE1IS = 3
ARM64_TLBI_VAAE1IS = 4
ARM64_TLBI_VALE1IS = 5
ARM64_TLBI_VAALE1IS = 6
ARM64_TLBI_ALLE2IS = 7
ARM64_TLBI_VAE2IS = 8
ARM64_TLBI_ALLE1IS = 9
ARM64_TLBI_VALE2IS = 10
ARM64_TLBI_VMALLS12E1IS = 11
ARM64_TLBI_ALLE3IS = 12
ARM64_TLBI_VAE3IS = 13
ARM64_TLBI_VALE3IS = 14
ARM64_TLBI_IPAS2E1IS = 15
ARM64_TLBI_IPAS2LE1IS = 16
ARM64_TLBI_IPAS2E1 = 17
ARM64_TLBI_IPAS2LE1 = 18
ARM64_TLBI_VMALLE1 = 19
ARM64_TLBI_VAE1 = 20
ARM64_TLBI_ASIDE1 = 21
ARM64_TLBI_VAAE1 = 22
ARM64_TLBI_VALE1 = 23
ARM64_TLBI_VAALE1 = 24
ARM64_TLBI_ALLE2 = 25
ARM64_TLBI_VAE2 = 26
ARM64_TLBI_ALLE1 = 27
ARM64_TLBI_VALE2 = 28
ARM64_TLBI_VMALLS12E1 = 29
ARM64_TLBI_ALLE3 = 30
ARM64_TLBI_VAE3 = 31
ARM64_TLBI_VALE3 = 32
ARM64_AT_S1E1R = 33
ARM64_AT_S1E1W = 34
ARM64_AT_S1E0R = 35
ARM64_AT_S1E0W = 36
ARM64_AT_S1E2R = 37
ARM64_AT_S1E2W = 38
ARM64_AT_S12E1R = 39
ARM64_AT_S12E1W = 40
ARM64_AT_S12E0R = 41
ARM64_AT_S12E0W = 42
ARM64_AT_S1E3R = 43
ARM64_AT_S1E3W = 44

ARM64_DC_INVALID = 0
ARM64_DC_ZVA = 1
ARM64_DC_IVAC = 2
ARM64_DC_ISW = 3
ARM64_DC_CVAC = 4
ARM64_DC_CSW = 5
ARM64_DC_CVAU = 6
ARM64_DC_CIVAC = 7
ARM64_DC_CISW = 8

ARM64_IC_INVALID = 0
ARM64_IC_IALLUIS = 1
ARM64_IC_IALLU = 2
ARM64_IC_IVAU = 3

ARM64_PRFM_INVALID = 0
ARM64_PRFM_PLDL1KEEP = 0x00+1
ARM64_PRFM_PLDL1STRM = 0x01+1
ARM64_PRFM_PLDL2KEEP = 0x02+1
ARM64_PRFM_PLDL2STRM = 0x03+1
ARM64_PRFM_PLDL3KEEP = 0x04+1
ARM64_PRFM_PLDL3STRM = 0x05+1
ARM64_PRFM_PLIL1KEEP = 0x08+1
ARM64_PRFM_PLIL1STRM = 0x09+1
ARM64_PRFM_PLIL2KEEP = 0x0a+1
ARM64_PRFM_PLIL2STRM = 0x0b+1
ARM64_PRFM_PLIL3KEEP = 0x0c+1
ARM64_PRFM_PLIL3STRM = 0x0d+1
ARM64_PRFM_PSTL1KEEP = 0x10+1
ARM64_PRFM_PSTL1STRM = 0x11+1
ARM64_PRFM_PSTL2KEEP = 0x12+1
ARM64_PRFM_PSTL2STRM = 0x13+1
ARM64_PRFM_PSTL3KEEP = 0x14+1
ARM64_PRFM_PSTL3STRM = 0x15+1

ARM64_REG_INVALID = 0
ARM64_REG_X29 = 1
ARM64_REG_X30 = 2
ARM64_REG_NZCV = 3
ARM64_REG_SP = 4
ARM64_REG_WSP = 5
ARM64_REG_WZR = 6
ARM64_REG_XZR = 7
ARM64_REG_B0 = 8
ARM64_REG_B1 = 9
ARM64_REG_B2 = 10
ARM64_REG_B3 = 11
ARM64_REG_B4 = 12
ARM64_REG_B5 = 13
ARM64_REG_B6 = 14
ARM64_REG_B7 = 15
ARM64_REG_B8 = 16
ARM64_REG_B9 = 17
ARM64_REG_B10 = 18
ARM64_REG_B11 = 19
ARM64_REG_B12 = 20
ARM64_REG_B13 = 21
ARM64_REG_B14 = 22
ARM64_REG_B15 = 23
ARM64_REG_B16 = 24
ARM64_REG_B17 = 25
ARM64_REG_B18 = 26
ARM64_REG_B19 = 27
ARM64_REG_B20 = 28
ARM64_REG_B21 = 29
ARM64_REG_B22 = 30
ARM64_REG_B23 = 31
ARM64_REG_B24 = 32
ARM64_REG_B25 = 33
ARM64_REG_B26 = 34
ARM64_REG_B27 = 35
ARM64_REG_B28 = 36
ARM64_REG_B29 = 37
ARM64_REG_B30 = 38
ARM64_REG_B31 = 39
ARM64_REG_D0 = 40
ARM64_REG_D1 = 41
ARM64_REG_D2 = 42
ARM64_REG_D3 = 43
ARM64_REG_D4 = 44
ARM64_REG_D5 = 45
ARM64_REG_D6 = 46
ARM64_REG_D7 = 47
ARM64_REG_D8 = 48
ARM64_REG_D9 = 49
ARM64_REG_D10 = 50
ARM64_REG_D11 = 51
ARM64_REG_D12 = 52
ARM64_REG_D13 = 53
ARM64_REG_D14 = 54
ARM64_REG_D15 = 55
ARM64_REG_D16 = 56
ARM64_REG_D17 = 57
ARM64_REG_D18 = 58
ARM64_REG_D19 = 59
ARM64_REG_D20 = 60
ARM64_REG_D21 = 61
ARM64_REG_D22 = 62
ARM64_REG_D23 = 63
ARM64_REG_D24 = 64
ARM64_REG_D25 = 65
ARM64_REG_D26 = 66
ARM64_REG_D27 = 67
ARM64_REG_D28 = 68
ARM64_REG_D29 = 69
ARM64_REG_D30 = 70
ARM64_REG_D31 = 71
ARM64_REG_H0 = 72
ARM64_REG_H1 = 73
ARM64_REG_H2 = 74
ARM64_REG_H3 = 75
ARM64_REG_H4 = 76
ARM64_REG_H5 = 77
ARM64_REG_H6 = 78
ARM64_REG_H7 = 79
ARM64_REG_H8 = 80
ARM64_REG_H9 = 81
ARM64_REG_H10 = 82
ARM64_REG_H11 = 83
ARM64_REG_H12 = 84
ARM64_REG_H13 = 85
ARM64_REG_H14 = 86
ARM64_REG_H15 = 87
ARM64_REG_H16 = 88
ARM64_REG_H17 = 89
ARM64_REG_H18 = 90
ARM64_REG_H19 = 91
ARM64_REG_H20 = 92
ARM64_REG_H21 = 93
ARM64_REG_H22 = 94
ARM64_REG_H23 = 95
ARM64_REG_H24 = 96
ARM64_REG_H25 = 97
ARM64_REG_H26 = 98
ARM64_REG_H27 = 99
ARM64_REG_H28 = 100
ARM64_REG_H29 = 101
ARM64_REG_H30 = 102
ARM64_REG_H31 = 103
ARM64_REG_Q0 = 104
ARM64_REG_Q1 = 105
ARM64_REG_Q2 = 106
ARM64_REG_Q3 = 107
ARM64_REG_Q4 = 108
ARM64_REG_Q5 = 109
ARM64_REG_Q6 = 110
ARM64_REG_Q7 = 111
ARM64_REG_Q8 = 112
ARM64_REG_Q9 = 113
ARM64_REG_Q10 = 114
ARM64_REG_Q11 = 115
ARM64_REG_Q12 = 116
ARM64_REG_Q13 = 117
ARM64_REG_Q14 = 118
ARM64_REG_Q15 = 119
ARM64_REG_Q16 = 120
ARM64_REG_Q17 = 121
ARM64_REG_Q18 = 122
ARM64_REG_Q19 = 123
ARM64_REG_Q20 = 124
ARM64_REG_Q21 = 125
ARM64_REG_Q22 = 126
ARM64_REG_Q23 = 127
ARM64_REG_Q24 = 128
ARM64_REG_Q25 = 129
ARM64_REG_Q26 = 130
ARM64_REG_Q27 = 131
ARM64_REG_Q28 = 132
ARM64_REG_Q29 = 133
ARM64_REG_Q30 = 134
ARM64_REG_Q31 = 135
ARM64_REG_S0 = 136
ARM64_REG_S1 = 137
ARM64_REG_S2 = 138
ARM64_REG_S3 = 139
ARM64_REG_S4 = 140
ARM64_REG_S5 = 141
ARM64_REG_S6 = 142
ARM64_REG_S7 = 143
ARM64_REG_S8 = 144
ARM64_REG_S9 = 145
ARM64_REG_S10 = 146
ARM64_REG_S11 = 147
ARM64_REG_S12 = 148
ARM64_REG_S13 = 149
ARM64_REG_S14 = 150
ARM64_REG_S15 = 151
ARM64_REG_S16 = 152
ARM64_REG_S17 = 153
ARM64_REG_S18 = 154
ARM64_REG_S19 = 155
ARM64_REG_S20 = 156
ARM64_REG_S21 = 157
ARM64_REG_S22 = 158
ARM64_REG_S23 = 159
ARM64_REG_S24 = 160
ARM64_REG_S25 = 161
ARM64_REG_S26 = 162
ARM64_REG_S27 = 163
ARM64_REG_S28 = 164
ARM64_REG_S29 = 165
ARM64_REG_S30 = 166
ARM64_REG_S31 = 167
ARM64_REG_W0 = 168
ARM64_REG_W1 = 169
ARM64_REG_W2 = 170
ARM64_REG_W3 = 171
ARM64_REG_W4 = 172
ARM64_REG_W5 = 173
ARM64_REG_W6 = 174
ARM64_REG_W7 = 175
ARM64_REG_W8 = 176
ARM64_REG_W9 = 177
ARM64_REG_W10 = 178
ARM64_REG_W11 = 179
ARM64_REG_W12 = 180
ARM64_REG_W13 = 181
ARM64_REG_W14 = 182
ARM64_REG_W15 = 183
ARM64_REG_W16 = 184
ARM64_REG_W17 = 185
ARM64_REG_W18 = 186
ARM64_REG_W19 = 187
ARM64_REG_W20 = 188
ARM64_REG_W21 = 189
ARM64_REG_W22 = 190
ARM64_REG_W23 = 191
ARM64_REG_W24 = 192
ARM64_REG_W25 = 193
ARM64_REG_W26 = 194
ARM64_REG_W27 = 195
ARM64_REG_W28 = 196
ARM64_REG_W29 = 197
ARM64_REG_W30 = 198
ARM64_REG_X0 = 199
ARM64_REG_X1 = 200
ARM64_REG_X2 = 201
ARM64_REG_X3 = 202
ARM64_REG_X4 = 203
ARM64_REG_X5 = 204
ARM64_REG_X6 = 205
ARM64_REG_X7 = 206
ARM64_REG_X8 = 207
ARM64_REG_X9 = 208
ARM64_REG_X10 = 209
ARM64_REG_X11 = 210
ARM64_REG_X12 = 211
ARM64_REG_X13 = 212
ARM64_REG_X14 = 213
ARM64_REG_X15 = 214
ARM64_REG_X16 = 215
ARM64_REG_X17 = 216
ARM64_REG_X18 = 217
ARM64_REG_X19 = 218
ARM64_REG_X20 = 219
ARM64_REG_X21 = 220
ARM64_REG_X22 = 221
ARM64_REG_X23 = 222
ARM64_REG_X24 = 223
ARM64_REG_X25 = 224
ARM64_REG_X26 = 225
ARM64_REG_X27 = 226
ARM64_REG_X28 = 227
ARM64_REG_V0 = 228
ARM64_REG_V1 = 229
ARM64_REG_V2 = 230
ARM64_REG_V3 = 231
ARM64_REG_V4 = 232
ARM64_REG_V5 = 233
ARM64_REG_V6 = 234
ARM64_REG_V7 = 235
ARM64_REG_V8 = 236
ARM64_REG_V9 = 237
ARM64_REG_V10 = 238
ARM64_REG_V11 = 239
ARM64_REG_V12 = 240
ARM64_REG_V13 = 241
ARM64_REG_V14 = 242
ARM64_REG_V15 = 243
ARM64_REG_V16 = 244
ARM64_REG_V17 = 245
ARM64_REG_V18 = 246
ARM64_REG_V19 = 247
ARM64_REG_V20 = 248
ARM64_REG_V21 = 249
ARM64_REG_V22 = 250
ARM64_REG_V23 = 251
ARM64_REG_V24 = 252
ARM64_REG_V25 = 253
ARM64_REG_V26 = 254
ARM64_REG_V27 = 255
ARM64_REG_V28 = 256
ARM64_REG_V29 = 257
ARM64_REG_V30 = 258
ARM64_REG_V31 = 259
ARM64_REG_ENDING = 260
ARM64_REG_IP0 = ARM64_REG_X16
ARM64_REG_IP1 = ARM64_REG_X17
ARM64_REG_FP = ARM64_REG_X29
ARM64_REG_LR = ARM64_REG_X30

ARM64_INS_INVALID = 0
ARM64_INS_ABS = 1
ARM64_INS_ADC = 2
ARM64_INS_ADDHN = 3
ARM64_INS_ADDHN2 = 4
ARM64_INS_ADDP = 5
ARM64_INS_ADD = 6
ARM64_INS_ADDV = 7
ARM64_INS_ADR = 8
ARM64_INS_ADRP = 9
ARM64_INS_AESD = 10
ARM64_INS_AESE = 11
ARM64_INS_AESIMC = 12
ARM64_INS_AESMC = 13
ARM64_INS_AND = 14
ARM64_INS_ASR = 15
ARM64_INS_B = 16
ARM64_INS_BFM = 17
ARM64_INS_BIC = 18
ARM64_INS_BIF = 19
ARM64_INS_BIT = 20
ARM64_INS_BL = 21
ARM64_INS_BLR = 22
ARM64_INS_BR = 23
ARM64_INS_BRK = 24
ARM64_INS_BSL = 25
ARM64_INS_CBNZ = 26
ARM64_INS_CBZ = 27
ARM64_INS_CCMN = 28
ARM64_INS_CCMP = 29
ARM64_INS_CLREX = 30
ARM64_INS_CLS = 31
ARM64_INS_CLZ = 32
ARM64_INS_CMEQ = 33
ARM64_INS_CMGE = 34
ARM64_INS_CMGT = 35
ARM64_INS_CMHI = 36
ARM64_INS_CMHS = 37
ARM64_INS_CMLE = 38
ARM64_INS_CMLT = 39
ARM64_INS_CMTST = 40
ARM64_INS_CNT = 41
ARM64_INS_MOV = 42
ARM64_INS_CRC32B = 43
ARM64_INS_CRC32CB = 44
ARM64_INS_CRC32CH = 45
ARM64_INS_CRC32CW = 46
ARM64_INS_CRC32CX = 47
ARM64_INS_CRC32H = 48
ARM64_INS_CRC32W = 49
ARM64_INS_CRC32X = 50
ARM64_INS_CSEL = 51
ARM64_INS_CSINC = 52
ARM64_INS_CSINV = 53
ARM64_INS_CSNEG = 54
ARM64_INS_DCPS1 = 55
ARM64_INS_DCPS2 = 56
ARM64_INS_DCPS3 = 57
ARM64_INS_DMB = 58
ARM64_INS_DRPS = 59
ARM64_INS_DSB = 60
ARM64_INS_DUP = 61
ARM64_INS_EON = 62
ARM64_INS_EOR = 63
ARM64_INS_ERET = 64
ARM64_INS_EXTR = 65
ARM64_INS_EXT = 66
ARM64_INS_FABD = 67
ARM64_INS_FABS = 68
ARM64_INS_FACGE = 69
ARM64_INS_FACGT = 70
ARM64_INS_FADD = 71
ARM64_INS_FADDP = 72
ARM64_INS_FCCMP = 73
ARM64_INS_FCCMPE = 74
ARM64_INS_FCMEQ = 75
ARM64_INS_FCMGE = 76
ARM64_INS_FCMGT = 77
ARM64_INS_FCMLE = 78
ARM64_INS_FCMLT = 79
ARM64_INS_FCMP = 80
ARM64_INS_FCMPE = 81
ARM64_INS_FCSEL = 82
ARM64_INS_FCVTAS = 83
ARM64_INS_FCVTAU = 84
ARM64_INS_FCVT = 85
ARM64_INS_FCVTL = 86
ARM64_INS_FCVTL2 = 87
ARM64_INS_FCVTMS = 88
ARM64_INS_FCVTMU = 89
ARM64_INS_FCVTNS = 90
ARM64_INS_FCVTNU = 91
ARM64_INS_FCVTN = 92
ARM64_INS_FCVTN2 = 93
ARM64_INS_FCVTPS = 94
ARM64_INS_FCVTPU = 95
ARM64_INS_FCVTXN = 96
ARM64_INS_FCVTXN2 = 97
ARM64_INS_FCVTZS = 98
ARM64_INS_FCVTZU = 99
ARM64_INS_FDIV = 100
ARM64_INS_FMADD = 101
ARM64_INS_FMAX = 102
ARM64_INS_FMAXNM = 103
ARM64_INS_FMAXNMP = 104
ARM64_INS_FMAXNMV = 105
ARM64_INS_FMAXP = 106
ARM64_INS_FMAXV = 107
ARM64_INS_FMIN = 108
ARM64_INS_FMINNM = 109
ARM64_INS_FMINNMP = 110
ARM64_INS_FMINNMV = 111
ARM64_INS_FMINP = 112
ARM64_INS_FMINV = 113
ARM64_INS_FMLA = 114
ARM64_INS_FMLS = 115
ARM64_INS_FMOV = 116
ARM64_INS_FMSUB = 117
ARM64_INS_FMUL = 118
ARM64_INS_FMULX = 119
ARM64_INS_FNEG = 120
ARM64_INS_FNMADD = 121
ARM64_INS_FNMSUB = 122
ARM64_INS_FNMUL = 123
ARM64_INS_FRECPE = 124
ARM64_INS_FRECPS = 125
ARM64_INS_FRECPX = 126
ARM64_INS_FRINTA = 127
ARM64_INS_FRINTI = 128
ARM64_INS_FRINTM = 129
ARM64_INS_FRINTN = 130
ARM64_INS_FRINTP = 131
ARM64_INS_FRINTX = 132
ARM64_INS_FRINTZ = 133
ARM64_INS_FRSQRTE = 134
ARM64_INS_FRSQRTS = 135
ARM64_INS_FSQRT = 136
ARM64_INS_FSUB = 137
ARM64_INS_HINT = 138
ARM64_INS_HLT = 139
ARM64_INS_HVC = 140
ARM64_INS_INS = 141
ARM64_INS_ISB = 142
ARM64_INS_LD1 = 143
ARM64_INS_LD1R = 144
ARM64_INS_LD2R = 145
ARM64_INS_LD2 = 146
ARM64_INS_LD3R = 147
ARM64_INS_LD3 = 148
ARM64_INS_LD4 = 149
ARM64_INS_LD4R = 150
ARM64_INS_LDARB = 151
ARM64_INS_LDARH = 152
ARM64_INS_LDAR = 153
ARM64_INS_LDAXP = 154
ARM64_INS_LDAXRB = 155
ARM64_INS_LDAXRH = 156
ARM64_INS_LDAXR = 157
ARM64_INS_LDNP = 158
ARM64_INS_LDP = 159
ARM64_INS_LDPSW = 160
ARM64_INS_LDRB = 161
ARM64_INS_LDR = 162
ARM64_INS_LDRH = 163
ARM64_INS_LDRSB = 164
ARM64_INS_LDRSH = 165
ARM64_INS_LDRSW = 166
ARM64_INS_LDTRB = 167
ARM64_INS_LDTRH = 168
ARM64_INS_LDTRSB = 169
ARM64_INS_LDTRSH = 170
ARM64_INS_LDTRSW = 171
ARM64_INS_LDTR = 172
ARM64_INS_LDURB = 173
ARM64_INS_LDUR = 174
ARM64_INS_LDURH = 175
ARM64_INS_LDURSB = 176
ARM64_INS_LDURSH = 177
ARM64_INS_LDURSW = 178
ARM64_INS_LDXP = 179
ARM64_INS_LDXRB = 180
ARM64_INS_LDXRH = 181
ARM64_INS_LDXR = 182
ARM64_INS_LSL = 183
ARM64_INS_LSR = 184
ARM64_INS_MADD = 185
ARM64_INS_MLA = 186
ARM64_INS_MLS = 187
ARM64_INS_MOVI = 188
ARM64_INS_MOVK = 189
ARM64_INS_MOVN = 190
ARM64_INS_MOVZ = 191
ARM64_INS_MRS = 192
ARM64_INS_MSR = 193
ARM64_INS_MSUB = 194
ARM64_INS_MUL = 195
ARM64_INS_MVNI = 196
ARM64_INS_NEG = 197
ARM64_INS_NOT = 198
ARM64_INS_ORN = 199
ARM64_INS_ORR = 200
ARM64_INS_PMULL2 = 201
ARM64_INS_PMULL = 202
ARM64_INS_PMUL = 203
ARM64_INS_PRFM = 204
ARM64_INS_PRFUM = 205
ARM64_INS_RADDHN = 206
ARM64_INS_RADDHN2 = 207
ARM64_INS_RBIT = 208
ARM64_INS_RET = 209
ARM64_INS_REV16 = 210
ARM64_INS_REV32 = 211
ARM64_INS_REV64 = 212
ARM64_INS_REV = 213
ARM64_INS_ROR = 214
ARM64_INS_RSHRN2 = 215
ARM64_INS_RSHRN = 216
ARM64_INS_RSUBHN = 217
ARM64_INS_RSUBHN2 = 218
ARM64_INS_SABAL2 = 219
ARM64_INS_SABAL = 220
ARM64_INS_SABA = 221
ARM64_INS_SABDL2 = 222
ARM64_INS_SABDL = 223
ARM64_INS_SABD = 224
ARM64_INS_SADALP = 225
ARM64_INS_SADDLP = 226
ARM64_INS_SADDLV = 227
ARM64_INS_SADDL2 = 228
ARM64_INS_SADDL = 229
ARM64_INS_SADDW2 = 230
ARM64_INS_SADDW = 231
ARM64_INS_SBC = 232
ARM64_INS_SBFM = 233
ARM64_INS_SCVTF = 234
ARM64_INS_SDIV = 235
ARM64_INS_SHA1C = 236
ARM64_INS_SHA1H = 237
ARM64_INS_SHA1M = 238
ARM64_INS_SHA1P = 239
ARM64_INS_SHA1SU0 = 240
ARM64_INS_SHA1SU1 = 241
ARM64_INS_SHA256H2 = 242
ARM64_INS_SHA256H = 243
ARM64_INS_SHA256SU0 = 244
ARM64_INS_SHA256SU1 = 245
ARM64_INS_SHADD = 246
ARM64_INS_SHLL2 = 247
ARM64_INS_SHLL = 248
ARM64_INS_SHL = 249
ARM64_INS_SHRN2 = 250
ARM64_INS_SHRN = 251
ARM64_INS_SHSUB = 252
ARM64_INS_SLI = 253
ARM64_INS_SMADDL = 254
ARM64_INS_SMAXP = 255
ARM64_INS_SMAXV = 256
ARM64_INS_SMAX = 257
ARM64_INS_SMC = 258
ARM64_INS_SMINP = 259
ARM64_INS_SMINV = 260
ARM64_INS_SMIN = 261
ARM64_INS_SMLAL2 = 262
ARM64_INS_SMLAL = 263
ARM64_INS_SMLSL2 = 264
ARM64_INS_SMLSL = 265
ARM64_INS_SMOV = 266
ARM64_INS_SMSUBL = 267
ARM64_INS_SMULH = 268
ARM64_INS_SMULL2 = 269
ARM64_INS_SMULL = 270
ARM64_INS_SQABS = 271
ARM64_INS_SQADD = 272
ARM64_INS_SQDMLAL = 273
ARM64_INS_SQDMLAL2 = 274
ARM64_INS_SQDMLSL = 275
ARM64_INS_SQDMLSL2 = 276
ARM64_INS_SQDMULH = 277
ARM64_INS_SQDMULL = 278
ARM64_INS_SQDMULL2 = 279
ARM64_INS_SQNEG = 280
ARM64_INS_SQRDMULH = 281
ARM64_INS_SQRSHL = 282
ARM64_INS_SQRSHRN = 283
ARM64_INS_SQRSHRN2 = 284
ARM64_INS_SQRSHRUN = 285
ARM64_INS_SQRSHRUN2 = 286
ARM64_INS_SQSHLU = 287
ARM64_INS_SQSHL = 288
ARM64_INS_SQSHRN = 289
ARM64_INS_SQSHRN2 = 290
ARM64_INS_SQSHRUN = 291
ARM64_INS_SQSHRUN2 = 292
ARM64_INS_SQSUB = 293
ARM64_INS_SQXTN2 = 294
ARM64_INS_SQXTN = 295
ARM64_INS_SQXTUN2 = 296
ARM64_INS_SQXTUN = 297
ARM64_INS_SRHADD = 298
ARM64_INS_SRI = 299
ARM64_INS_SRSHL = 300
ARM64_INS_SRSHR = 301
ARM64_INS_SRSRA = 302
ARM64_INS_SSHLL2 = 303
ARM64_INS_SSHLL = 304
ARM64_INS_SSHL = 305
ARM64_INS_SSHR = 306
ARM64_INS_SSRA = 307
ARM64_INS_SSUBL2 = 308
ARM64_INS_SSUBL = 309
ARM64_INS_SSUBW2 = 310
ARM64_INS_SSUBW = 311
ARM64_INS_ST1 = 312
ARM64_INS_ST2 = 313
ARM64_INS_ST3 = 314
ARM64_INS_ST4 = 315
ARM64_INS_STLRB = 316
ARM64_INS_STLRH = 317
ARM64_INS_STLR = 318
ARM64_INS_STLXP = 319
ARM64_INS_STLXRB = 320
ARM64_INS_STLXRH = 321
ARM64_INS_STLXR = 322
ARM64_INS_STNP = 323
ARM64_INS_STP = 324
ARM64_INS_STRB = 325
ARM64_INS_STR = 326
ARM64_INS_STRH = 327
ARM64_INS_STTRB = 328
ARM64_INS_STTRH = 329
ARM64_INS_STTR = 330
ARM64_INS_STURB = 331
ARM64_INS_STUR = 332
ARM64_INS_STURH = 333
ARM64_INS_STXP = 334
ARM64_INS_STXRB = 335
ARM64_INS_STXRH = 336
ARM64_INS_STXR = 337
ARM64_INS_SUBHN = 338
ARM64_INS_SUBHN2 = 339
ARM64_INS_SUB = 340
ARM64_INS_SUQADD = 341
ARM64_INS_SVC = 342
ARM64_INS_SYSL = 343
ARM64_INS_SYS = 344
ARM64_INS_TBL = 345
ARM64_INS_TBNZ = 346
ARM64_INS_TBX = 347
ARM64_INS_TBZ = 348
ARM64_INS_TRN1 = 349
ARM64_INS_TRN2 = 350
ARM64_INS_UABAL2 = 351
ARM64_INS_UABAL = 352
ARM64_INS_UABA = 353
ARM64_INS_UABDL2 = 354
ARM64_INS_UABDL = 355
ARM64_INS_UABD = 356
ARM64_INS_UADALP = 357
ARM64_INS_UADDLP = 358
ARM64_INS_UADDLV = 359
ARM64_INS_UADDL2 = 360
ARM64_INS_UADDL = 361
ARM64_INS_UADDW2 = 362
ARM64_INS_UADDW = 363
ARM64_INS_UBFM = 364
ARM64_INS_UCVTF = 365
ARM64_INS_UDIV = 366
ARM64_INS_UHADD = 367
ARM64_INS_UHSUB = 368
ARM64_INS_UMADDL = 369
ARM64_INS_UMAXP = 370
ARM64_INS_UMAXV = 371
ARM64_INS_UMAX = 372
ARM64_INS_UMINP = 373
ARM64_INS_UMINV = 374
ARM64_INS_UMIN = 375
ARM64_INS_UMLAL2 = 376
ARM64_INS_UMLAL = 377
ARM64_INS_UMLSL2 = 378
ARM64_INS_UMLSL = 379
ARM64_INS_UMOV = 380
ARM64_INS_UMSUBL = 381
ARM64_INS_UMULH = 382
ARM64_INS_UMULL2 = 383
ARM64_INS_UMULL = 384
ARM64_INS_UQADD = 385
ARM64_INS_UQRSHL = 386
ARM64_INS_UQRSHRN = 387
ARM64_INS_UQRSHRN2 = 388
ARM64_INS_UQSHL = 389
ARM64_INS_UQSHRN = 390
ARM64_INS_UQSHRN2 = 391
ARM64_INS_UQSUB = 392
ARM64_INS_UQXTN2 = 393
ARM64_INS_UQXTN = 394
ARM64_INS_URECPE = 395
ARM64_INS_URHADD = 396
ARM64_INS_URSHL = 397
ARM64_INS_URSHR = 398
ARM64_INS_URSQRTE = 399
ARM64_INS_URSRA = 400
ARM64_INS_USHLL2 = 401
ARM64_INS_USHLL = 402
ARM64_INS_USHL = 403
ARM64_INS_USHR = 404
ARM64_INS_USQADD = 405
ARM64_INS_USRA = 406
ARM64_INS_USUBL2 = 407
ARM64_INS_USUBL = 408
ARM64_INS_USUBW2 = 409
ARM64_INS_USUBW = 410
ARM64_INS_UZP1 = 411
ARM64_INS_UZP2 = 412
ARM64_INS_XTN2 = 413
ARM64_INS_XTN = 414
ARM64_INS_ZIP1 = 415
ARM64_INS_ZIP2 = 416
ARM64_INS_MNEG = 417
ARM64_INS_UMNEGL = 418
ARM64_INS_SMNEGL = 419
ARM64_INS_NOP = 420
ARM64_INS_YIELD = 421
ARM64_INS_WFE = 422
ARM64_INS_WFI = 423
ARM64_INS_SEV = 424
ARM64_INS_SEVL = 425
ARM64_INS_NGC = 426
ARM64_INS_SBFIZ = 427
ARM64_INS_UBFIZ = 428
ARM64_INS_SBFX = 429
ARM64_INS_UBFX = 430
ARM64_INS_BFI = 431
ARM64_INS_BFXIL = 432
ARM64_INS_CMN = 433
ARM64_INS_MVN = 434
ARM64_INS_TST = 435
ARM64_INS_CSET = 436
ARM64_INS_CINC = 437
ARM64_INS_CSETM = 438
ARM64_INS_CINV = 439
ARM64_INS_CNEG = 440
ARM64_INS_SXTB = 441
ARM64_INS_SXTH = 442
ARM64_INS_SXTW = 443
ARM64_INS_CMP = 444
ARM64_INS_UXTB = 445
ARM64_INS_UXTH = 446
ARM64_INS_UXTW = 447
ARM64_INS_IC = 448
ARM64_INS_DC = 449
ARM64_INS_AT = 450
ARM64_INS_TLBI = 451
ARM64_INS_NEGS = 452
ARM64_INS_NGCS = 453
ARM64_INS_ENDING = 454

ARM64_GRP_INVALID = 0
ARM64_GRP_JUMP = 1
ARM64_GRP_CALL = 2
ARM64_GRP_RET = 3
ARM64_GRP_INT = 4
ARM64_GRP_PRIVILEGE = 6
ARM64_GRP_BRANCH_RELATIVE = 7
ARM64_GRP_CRYPTO = 128
ARM64_GRP_FPARMV8 = 129
ARM64_GRP_NEON = 130
ARM64_GRP_CRC = 131
ARM64_GRP_ENDING = 132



# For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [ppc_const.py]

PPC_BC_INVALID = 0
PPC_BC_LT = (0<<5)|12
PPC_BC_LE = (1<<5)|4
PPC_BC_EQ = (2<<5)|12
PPC_BC_GE = (0<<5)|4
PPC_BC_GT = (1<<5)|12
PPC_BC_NE = (2<<5)|4
PPC_BC_UN = (3<<5)|12
PPC_BC_NU = (3<<5)|4
PPC_BC_SO = (4<<5)|12
PPC_BC_NS = (4<<5)|4

PPC_BH_INVALID = 0
PPC_BH_PLUS = 1
PPC_BH_MINUS = 2

PPC_OP_INVALID = 0
PPC_OP_REG = 1
PPC_OP_IMM = 2
PPC_OP_MEM = 3
PPC_OP_CRX = 64

PPC_REG_INVALID = 0
PPC_REG_CARRY = 1
PPC_REG_CR0 = 2
PPC_REG_CR1 = 3
PPC_REG_CR2 = 4
PPC_REG_CR3 = 5
PPC_REG_CR4 = 6
PPC_REG_CR5 = 7
PPC_REG_CR6 = 8
PPC_REG_CR7 = 9
PPC_REG_CTR = 10
PPC_REG_F0 = 11
PPC_REG_F1 = 12
PPC_REG_F2 = 13
PPC_REG_F3 = 14
PPC_REG_F4 = 15
PPC_REG_F5 = 16
PPC_REG_F6 = 17
PPC_REG_F7 = 18
PPC_REG_F8 = 19
PPC_REG_F9 = 20
PPC_REG_F10 = 21
PPC_REG_F11 = 22
PPC_REG_F12 = 23
PPC_REG_F13 = 24
PPC_REG_F14 = 25
PPC_REG_F15 = 26
PPC_REG_F16 = 27
PPC_REG_F17 = 28
PPC_REG_F18 = 29
PPC_REG_F19 = 30
PPC_REG_F20 = 31
PPC_REG_F21 = 32
PPC_REG_F22 = 33
PPC_REG_F23 = 34
PPC_REG_F24 = 35
PPC_REG_F25 = 36
PPC_REG_F26 = 37
PPC_REG_F27 = 38
PPC_REG_F28 = 39
PPC_REG_F29 = 40
PPC_REG_F30 = 41
PPC_REG_F31 = 42
PPC_REG_LR = 43
PPC_REG_R0 = 44
PPC_REG_R1 = 45
PPC_REG_R2 = 46
PPC_REG_R3 = 47
PPC_REG_R4 = 48
PPC_REG_R5 = 49
PPC_REG_R6 = 50
PPC_REG_R7 = 51
PPC_REG_R8 = 52
PPC_REG_R9 = 53
PPC_REG_R10 = 54
PPC_REG_R11 = 55
PPC_REG_R12 = 56
PPC_REG_R13 = 57
PPC_REG_R14 = 58
PPC_REG_R15 = 59
PPC_REG_R16 = 60
PPC_REG_R17 = 61
PPC_REG_R18 = 62
PPC_REG_R19 = 63
PPC_REG_R20 = 64
PPC_REG_R21 = 65
PPC_REG_R22 = 66
PPC_REG_R23 = 67
PPC_REG_R24 = 68
PPC_REG_R25 = 69
PPC_REG_R26 = 70
PPC_REG_R27 = 71
PPC_REG_R28 = 72
PPC_REG_R29 = 73
PPC_REG_R30 = 74
PPC_REG_R31 = 75
PPC_REG_V0 = 76
PPC_REG_V1 = 77
PPC_REG_V2 = 78
PPC_REG_V3 = 79
PPC_REG_V4 = 80
PPC_REG_V5 = 81
PPC_REG_V6 = 82
PPC_REG_V7 = 83
PPC_REG_V8 = 84
PPC_REG_V9 = 85
PPC_REG_V10 = 86
PPC_REG_V11 = 87
PPC_REG_V12 = 88
PPC_REG_V13 = 89
PPC_REG_V14 = 90
PPC_REG_V15 = 91
PPC_REG_V16 = 92
PPC_REG_V17 = 93
PPC_REG_V18 = 94
PPC_REG_V19 = 95
PPC_REG_V20 = 96
PPC_REG_V21 = 97
PPC_REG_V22 = 98
PPC_REG_V23 = 99
PPC_REG_V24 = 100
PPC_REG_V25 = 101
PPC_REG_V26 = 102
PPC_REG_V27 = 103
PPC_REG_V28 = 104
PPC_REG_V29 = 105
PPC_REG_V30 = 106
PPC_REG_V31 = 107
PPC_REG_VRSAVE = 108
PPC_REG_VS0 = 109
PPC_REG_VS1 = 110
PPC_REG_VS2 = 111
PPC_REG_VS3 = 112
PPC_REG_VS4 = 113
PPC_REG_VS5 = 114
PPC_REG_VS6 = 115
PPC_REG_VS7 = 116
PPC_REG_VS8 = 117
PPC_REG_VS9 = 118
PPC_REG_VS10 = 119
PPC_REG_VS11 = 120
PPC_REG_VS12 = 121
PPC_REG_VS13 = 122
PPC_REG_VS14 = 123
PPC_REG_VS15 = 124
PPC_REG_VS16 = 125
PPC_REG_VS17 = 126
PPC_REG_VS18 = 127
PPC_REG_VS19 = 128
PPC_REG_VS20 = 129
PPC_REG_VS21 = 130
PPC_REG_VS22 = 131
PPC_REG_VS23 = 132
PPC_REG_VS24 = 133
PPC_REG_VS25 = 134
PPC_REG_VS26 = 135
PPC_REG_VS27 = 136
PPC_REG_VS28 = 137
PPC_REG_VS29 = 138
PPC_REG_VS30 = 139
PPC_REG_VS31 = 140
PPC_REG_VS32 = 141
PPC_REG_VS33 = 142
PPC_REG_VS34 = 143
PPC_REG_VS35 = 144
PPC_REG_VS36 = 145
PPC_REG_VS37 = 146
PPC_REG_VS38 = 147
PPC_REG_VS39 = 148
PPC_REG_VS40 = 149
PPC_REG_VS41 = 150
PPC_REG_VS42 = 151
PPC_REG_VS43 = 152
PPC_REG_VS44 = 153
PPC_REG_VS45 = 154
PPC_REG_VS46 = 155
PPC_REG_VS47 = 156
PPC_REG_VS48 = 157
PPC_REG_VS49 = 158
PPC_REG_VS50 = 159
PPC_REG_VS51 = 160
PPC_REG_VS52 = 161
PPC_REG_VS53 = 162
PPC_REG_VS54 = 163
PPC_REG_VS55 = 164
PPC_REG_VS56 = 165
PPC_REG_VS57 = 166
PPC_REG_VS58 = 167
PPC_REG_VS59 = 168
PPC_REG_VS60 = 169
PPC_REG_VS61 = 170
PPC_REG_VS62 = 171
PPC_REG_VS63 = 172
PPC_REG_Q0 = 173
PPC_REG_Q1 = 174
PPC_REG_Q2 = 175
PPC_REG_Q3 = 176
PPC_REG_Q4 = 177
PPC_REG_Q5 = 178
PPC_REG_Q6 = 179
PPC_REG_Q7 = 180
PPC_REG_Q8 = 181
PPC_REG_Q9 = 182
PPC_REG_Q10 = 183
PPC_REG_Q11 = 184
PPC_REG_Q12 = 185
PPC_REG_Q13 = 186
PPC_REG_Q14 = 187
PPC_REG_Q15 = 188
PPC_REG_Q16 = 189
PPC_REG_Q17 = 190
PPC_REG_Q18 = 191
PPC_REG_Q19 = 192
PPC_REG_Q20 = 193
PPC_REG_Q21 = 194
PPC_REG_Q22 = 195
PPC_REG_Q23 = 196
PPC_REG_Q24 = 197
PPC_REG_Q25 = 198
PPC_REG_Q26 = 199
PPC_REG_Q27 = 200
PPC_REG_Q28 = 201
PPC_REG_Q29 = 202
PPC_REG_Q30 = 203
PPC_REG_Q31 = 204
PPC_REG_RM = 205
PPC_REG_CTR8 = 206
PPC_REG_LR8 = 207
PPC_REG_CR1EQ = 208
PPC_REG_X2 = 209
PPC_REG_ENDING = 210

PPC_INS_INVALID = 0
PPC_INS_ADD = 1
PPC_INS_ADDC = 2
PPC_INS_ADDE = 3
PPC_INS_ADDI = 4
PPC_INS_ADDIC = 5
PPC_INS_ADDIS = 6
PPC_INS_ADDME = 7
PPC_INS_ADDZE = 8
PPC_INS_AND = 9
PPC_INS_ANDC = 10
PPC_INS_ANDIS = 11
PPC_INS_ANDI = 12
PPC_INS_ATTN = 13
PPC_INS_B = 14
PPC_INS_BA = 15
PPC_INS_BC = 16
PPC_INS_BCCTR = 17
PPC_INS_BCCTRL = 18
PPC_INS_BCL = 19
PPC_INS_BCLR = 20
PPC_INS_BCLRL = 21
PPC_INS_BCTR = 22
PPC_INS_BCTRL = 23
PPC_INS_BCT = 24
PPC_INS_BDNZ = 25
PPC_INS_BDNZA = 26
PPC_INS_BDNZL = 27
PPC_INS_BDNZLA = 28
PPC_INS_BDNZLR = 29
PPC_INS_BDNZLRL = 30
PPC_INS_BDZ = 31
PPC_INS_BDZA = 32
PPC_INS_BDZL = 33
PPC_INS_BDZLA = 34
PPC_INS_BDZLR = 35
PPC_INS_BDZLRL = 36
PPC_INS_BL = 37
PPC_INS_BLA = 38
PPC_INS_BLR = 39
PPC_INS_BLRL = 40
PPC_INS_BRINC = 41
PPC_INS_CMPB = 42
PPC_INS_CMPD = 43
PPC_INS_CMPDI = 44
PPC_INS_CMPLD = 45
PPC_INS_CMPLDI = 46
PPC_INS_CMPLW = 47
PPC_INS_CMPLWI = 48
PPC_INS_CMPW = 49
PPC_INS_CMPWI = 50
PPC_INS_CNTLZD = 51
PPC_INS_CNTLZW = 52
PPC_INS_CREQV = 53
PPC_INS_CRXOR = 54
PPC_INS_CRAND = 55
PPC_INS_CRANDC = 56
PPC_INS_CRNAND = 57
PPC_INS_CRNOR = 58
PPC_INS_CROR = 59
PPC_INS_CRORC = 60
PPC_INS_DCBA = 61
PPC_INS_DCBF = 62
PPC_INS_DCBI = 63
PPC_INS_DCBST = 64
PPC_INS_DCBT = 65
PPC_INS_DCBTST = 66
PPC_INS_DCBZ = 67
PPC_INS_DCBZL = 68
PPC_INS_DCCCI = 69
PPC_INS_DIVD = 70
PPC_INS_DIVDU = 71
PPC_INS_DIVW = 72
PPC_INS_DIVWU = 73
PPC_INS_DSS = 74
PPC_INS_DSSALL = 75
PPC_INS_DST = 76
PPC_INS_DSTST = 77
PPC_INS_DSTSTT = 78
PPC_INS_DSTT = 79
PPC_INS_EQV = 80
PPC_INS_EVABS = 81
PPC_INS_EVADDIW = 82
PPC_INS_EVADDSMIAAW = 83
PPC_INS_EVADDSSIAAW = 84
PPC_INS_EVADDUMIAAW = 85
PPC_INS_EVADDUSIAAW = 86
PPC_INS_EVADDW = 87
PPC_INS_EVAND = 88
PPC_INS_EVANDC = 89
PPC_INS_EVCMPEQ = 90
PPC_INS_EVCMPGTS = 91
PPC_INS_EVCMPGTU = 92
PPC_INS_EVCMPLTS = 93
PPC_INS_EVCMPLTU = 94
PPC_INS_EVCNTLSW = 95
PPC_INS_EVCNTLZW = 96
PPC_INS_EVDIVWS = 97
PPC_INS_EVDIVWU = 98
PPC_INS_EVEQV = 99
PPC_INS_EVEXTSB = 100
PPC_INS_EVEXTSH = 101
PPC_INS_EVLDD = 102
PPC_INS_EVLDDX = 103
PPC_INS_EVLDH = 104
PPC_INS_EVLDHX = 105
PPC_INS_EVLDW = 106
PPC_INS_EVLDWX = 107
PPC_INS_EVLHHESPLAT = 108
PPC_INS_EVLHHESPLATX = 109
PPC_INS_EVLHHOSSPLAT = 110
PPC_INS_EVLHHOSSPLATX = 111
PPC_INS_EVLHHOUSPLAT = 112
PPC_INS_EVLHHOUSPLATX = 113
PPC_INS_EVLWHE = 114
PPC_INS_EVLWHEX = 115
PPC_INS_EVLWHOS = 116
PPC_INS_EVLWHOSX = 117
PPC_INS_EVLWHOU = 118
PPC_INS_EVLWHOUX = 119
PPC_INS_EVLWHSPLAT = 120
PPC_INS_EVLWHSPLATX = 121
PPC_INS_EVLWWSPLAT = 122
PPC_INS_EVLWWSPLATX = 123
PPC_INS_EVMERGEHI = 124
PPC_INS_EVMERGEHILO = 125
PPC_INS_EVMERGELO = 126
PPC_INS_EVMERGELOHI = 127
PPC_INS_EVMHEGSMFAA = 128
PPC_INS_EVMHEGSMFAN = 129
PPC_INS_EVMHEGSMIAA = 130
PPC_INS_EVMHEGSMIAN = 131
PPC_INS_EVMHEGUMIAA = 132
PPC_INS_EVMHEGUMIAN = 133
PPC_INS_EVMHESMF = 134
PPC_INS_EVMHESMFA = 135
PPC_INS_EVMHESMFAAW = 136
PPC_INS_EVMHESMFANW = 137
PPC_INS_EVMHESMI = 138
PPC_INS_EVMHESMIA = 139
PPC_INS_EVMHESMIAAW = 140
PPC_INS_EVMHESMIANW = 141
PPC_INS_EVMHESSF = 142
PPC_INS_EVMHESSFA = 143
PPC_INS_EVMHESSFAAW = 144
PPC_INS_EVMHESSFANW = 145
PPC_INS_EVMHESSIAAW = 146
PPC_INS_EVMHESSIANW = 147
PPC_INS_EVMHEUMI = 148
PPC_INS_EVMHEUMIA = 149
PPC_INS_EVMHEUMIAAW = 150
PPC_INS_EVMHEUMIANW = 151
PPC_INS_EVMHEUSIAAW = 152
PPC_INS_EVMHEUSIANW = 153
PPC_INS_EVMHOGSMFAA = 154
PPC_INS_EVMHOGSMFAN = 155
PPC_INS_EVMHOGSMIAA = 156
PPC_INS_EVMHOGSMIAN = 157
PPC_INS_EVMHOGUMIAA = 158
PPC_INS_EVMHOGUMIAN = 159
PPC_INS_EVMHOSMF = 160
PPC_INS_EVMHOSMFA = 161
PPC_INS_EVMHOSMFAAW = 162
PPC_INS_EVMHOSMFANW = 163
PPC_INS_EVMHOSMI = 164
PPC_INS_EVMHOSMIA = 165
PPC_INS_EVMHOSMIAAW = 166
PPC_INS_EVMHOSMIANW = 167
PPC_INS_EVMHOSSF = 168
PPC_INS_EVMHOSSFA = 169
PPC_INS_EVMHOSSFAAW = 170
PPC_INS_EVMHOSSFANW = 171
PPC_INS_EVMHOSSIAAW = 172
PPC_INS_EVMHOSSIANW = 173
PPC_INS_EVMHOUMI = 174
PPC_INS_EVMHOUMIA = 175
PPC_INS_EVMHOUMIAAW = 176
PPC_INS_EVMHOUMIANW = 177
PPC_INS_EVMHOUSIAAW = 178
PPC_INS_EVMHOUSIANW = 179
PPC_INS_EVMRA = 180
PPC_INS_EVMWHSMF = 181
PPC_INS_EVMWHSMFA = 182
PPC_INS_EVMWHSMI = 183
PPC_INS_EVMWHSMIA = 184
PPC_INS_EVMWHSSF = 185
PPC_INS_EVMWHSSFA = 186
PPC_INS_EVMWHUMI = 187
PPC_INS_EVMWHUMIA = 188
PPC_INS_EVMWLSMIAAW = 189
PPC_INS_EVMWLSMIANW = 190
PPC_INS_EVMWLSSIAAW = 191
PPC_INS_EVMWLSSIANW = 192
PPC_INS_EVMWLUMI = 193
PPC_INS_EVMWLUMIA = 194
PPC_INS_EVMWLUMIAAW = 195
PPC_INS_EVMWLUMIANW = 196
PPC_INS_EVMWLUSIAAW = 197
PPC_INS_EVMWLUSIANW = 198
PPC_INS_EVMWSMF = 199
PPC_INS_EVMWSMFA = 200
PPC_INS_EVMWSMFAA = 201
PPC_INS_EVMWSMFAN = 202
PPC_INS_EVMWSMI = 203
PPC_INS_EVMWSMIA = 204
PPC_INS_EVMWSMIAA = 205
PPC_INS_EVMWSMIAN = 206
PPC_INS_EVMWSSF = 207
PPC_INS_EVMWSSFA = 208
PPC_INS_EVMWSSFAA = 209
PPC_INS_EVMWSSFAN = 210
PPC_INS_EVMWUMI = 211
PPC_INS_EVMWUMIA = 212
PPC_INS_EVMWUMIAA = 213
PPC_INS_EVMWUMIAN = 214
PPC_INS_EVNAND = 215
PPC_INS_EVNEG = 216
PPC_INS_EVNOR = 217
PPC_INS_EVOR = 218
PPC_INS_EVORC = 219
PPC_INS_EVRLW = 220
PPC_INS_EVRLWI = 221
PPC_INS_EVRNDW = 222
PPC_INS_EVSLW = 223
PPC_INS_EVSLWI = 224
PPC_INS_EVSPLATFI = 225
PPC_INS_EVSPLATI = 226
PPC_INS_EVSRWIS = 227
PPC_INS_EVSRWIU = 228
PPC_INS_EVSRWS = 229
PPC_INS_EVSRWU = 230
PPC_INS_EVSTDD = 231
PPC_INS_EVSTDDX = 232
PPC_INS_EVSTDH = 233
PPC_INS_EVSTDHX = 234
PPC_INS_EVSTDW = 235
PPC_INS_EVSTDWX = 236
PPC_INS_EVSTWHE = 237
PPC_INS_EVSTWHEX = 238
PPC_INS_EVSTWHO = 239
PPC_INS_EVSTWHOX = 240
PPC_INS_EVSTWWE = 241
PPC_INS_EVSTWWEX = 242
PPC_INS_EVSTWWO = 243
PPC_INS_EVSTWWOX = 244
PPC_INS_EVSUBFSMIAAW = 245
PPC_INS_EVSUBFSSIAAW = 246
PPC_INS_EVSUBFUMIAAW = 247
PPC_INS_EVSUBFUSIAAW = 248
PPC_INS_EVSUBFW = 249
PPC_INS_EVSUBIFW = 250
PPC_INS_EVXOR = 251
PPC_INS_EXTSB = 252
PPC_INS_EXTSH = 253
PPC_INS_EXTSW = 254
PPC_INS_EIEIO = 255
PPC_INS_FABS = 256
PPC_INS_FADD = 257
PPC_INS_FADDS = 258
PPC_INS_FCFID = 259
PPC_INS_FCFIDS = 260
PPC_INS_FCFIDU = 261
PPC_INS_FCFIDUS = 262
PPC_INS_FCMPU = 263
PPC_INS_FCPSGN = 264
PPC_INS_FCTID = 265
PPC_INS_FCTIDUZ = 266
PPC_INS_FCTIDZ = 267
PPC_INS_FCTIW = 268
PPC_INS_FCTIWUZ = 269
PPC_INS_FCTIWZ = 270
PPC_INS_FDIV = 271
PPC_INS_FDIVS = 272
PPC_INS_FMADD = 273
PPC_INS_FMADDS = 274
PPC_INS_FMR = 275
PPC_INS_FMSUB = 276
PPC_INS_FMSUBS = 277
PPC_INS_FMUL = 278
PPC_INS_FMULS = 279
PPC_INS_FNABS = 280
PPC_INS_FNEG = 281
PPC_INS_FNMADD = 282
PPC_INS_FNMADDS = 283
PPC_INS_FNMSUB = 284
PPC_INS_FNMSUBS = 285
PPC_INS_FRE = 286
PPC_INS_FRES = 287
PPC_INS_FRIM = 288
PPC_INS_FRIN = 289
PPC_INS_FRIP = 290
PPC_INS_FRIZ = 291
PPC_INS_FRSP = 292
PPC_INS_FRSQRTE = 293
PPC_INS_FRSQRTES = 294
PPC_INS_FSEL = 295
PPC_INS_FSQRT = 296
PPC_INS_FSQRTS = 297
PPC_INS_FSUB = 298
PPC_INS_FSUBS = 299
PPC_INS_ICBI = 300
PPC_INS_ICBT = 301
PPC_INS_ICCCI = 302
PPC_INS_ISEL = 303
PPC_INS_ISYNC = 304
PPC_INS_LA = 305
PPC_INS_LBZ = 306
PPC_INS_LBZCIX = 307
PPC_INS_LBZU = 308
PPC_INS_LBZUX = 309
PPC_INS_LBZX = 310
PPC_INS_LD = 311
PPC_INS_LDARX = 312
PPC_INS_LDBRX = 313
PPC_INS_LDCIX = 314
PPC_INS_LDU = 315
PPC_INS_LDUX = 316
PPC_INS_LDX = 317
PPC_INS_LFD = 318
PPC_INS_LFDU = 319
PPC_INS_LFDUX = 320
PPC_INS_LFDX = 321
PPC_INS_LFIWAX = 322
PPC_INS_LFIWZX = 323
PPC_INS_LFS = 324
PPC_INS_LFSU = 325
PPC_INS_LFSUX = 326
PPC_INS_LFSX = 327
PPC_INS_LHA = 328
PPC_INS_LHAU = 329
PPC_INS_LHAUX = 330
PPC_INS_LHAX = 331
PPC_INS_LHBRX = 332
PPC_INS_LHZ = 333
PPC_INS_LHZCIX = 334
PPC_INS_LHZU = 335
PPC_INS_LHZUX = 336
PPC_INS_LHZX = 337
PPC_INS_LI = 338
PPC_INS_LIS = 339
PPC_INS_LMW = 340
PPC_INS_LSWI = 341
PPC_INS_LVEBX = 342
PPC_INS_LVEHX = 343
PPC_INS_LVEWX = 344
PPC_INS_LVSL = 345
PPC_INS_LVSR = 346
PPC_INS_LVX = 347
PPC_INS_LVXL = 348
PPC_INS_LWA = 349
PPC_INS_LWARX = 350
PPC_INS_LWAUX = 351
PPC_INS_LWAX = 352
PPC_INS_LWBRX = 353
PPC_INS_LWZ = 354
PPC_INS_LWZCIX = 355
PPC_INS_LWZU = 356
PPC_INS_LWZUX = 357
PPC_INS_LWZX = 358
PPC_INS_LXSDX = 359
PPC_INS_LXVD2X = 360
PPC_INS_LXVDSX = 361
PPC_INS_LXVW4X = 362
PPC_INS_MBAR = 363
PPC_INS_MCRF = 364
PPC_INS_MCRFS = 365
PPC_INS_MFCR = 366
PPC_INS_MFCTR = 367
PPC_INS_MFDCR = 368
PPC_INS_MFFS = 369
PPC_INS_MFLR = 370
PPC_INS_MFMSR = 371
PPC_INS_MFOCRF = 372
PPC_INS_MFSPR = 373
PPC_INS_MFSR = 374
PPC_INS_MFSRIN = 375
PPC_INS_MFTB = 376
PPC_INS_MFVSCR = 377
PPC_INS_MSYNC = 378
PPC_INS_MTCRF = 379
PPC_INS_MTCTR = 380
PPC_INS_MTDCR = 381
PPC_INS_MTFSB0 = 382
PPC_INS_MTFSB1 = 383
PPC_INS_MTFSF = 384
PPC_INS_MTFSFI = 385
PPC_INS_MTLR = 386
PPC_INS_MTMSR = 387
PPC_INS_MTMSRD = 388
PPC_INS_MTOCRF = 389
PPC_INS_MTSPR = 390
PPC_INS_MTSR = 391
PPC_INS_MTSRIN = 392
PPC_INS_MTVSCR = 393
PPC_INS_MULHD = 394
PPC_INS_MULHDU = 395
PPC_INS_MULHW = 396
PPC_INS_MULHWU = 397
PPC_INS_MULLD = 398
PPC_INS_MULLI = 399
PPC_INS_MULLW = 400
PPC_INS_NAND = 401
PPC_INS_NEG = 402
PPC_INS_NOP = 403
PPC_INS_ORI = 404
PPC_INS_NOR = 405
PPC_INS_OR = 406
PPC_INS_ORC = 407
PPC_INS_ORIS = 408
PPC_INS_POPCNTD = 409
PPC_INS_POPCNTW = 410
PPC_INS_QVALIGNI = 411
PPC_INS_QVESPLATI = 412
PPC_INS_QVFABS = 413
PPC_INS_QVFADD = 414
PPC_INS_QVFADDS = 415
PPC_INS_QVFCFID = 416
PPC_INS_QVFCFIDS = 417
PPC_INS_QVFCFIDU = 418
PPC_INS_QVFCFIDUS = 419
PPC_INS_QVFCMPEQ = 420
PPC_INS_QVFCMPGT = 421
PPC_INS_QVFCMPLT = 422
PPC_INS_QVFCPSGN = 423
PPC_INS_QVFCTID = 424
PPC_INS_QVFCTIDU = 425
PPC_INS_QVFCTIDUZ = 426
PPC_INS_QVFCTIDZ = 427
PPC_INS_QVFCTIW = 428
PPC_INS_QVFCTIWU = 429
PPC_INS_QVFCTIWUZ = 430
PPC_INS_QVFCTIWZ = 431
PPC_INS_QVFLOGICAL = 432
PPC_INS_QVFMADD = 433
PPC_INS_QVFMADDS = 434
PPC_INS_QVFMR = 435
PPC_INS_QVFMSUB = 436
PPC_INS_QVFMSUBS = 437
PPC_INS_QVFMUL = 438
PPC_INS_QVFMULS = 439
PPC_INS_QVFNABS = 440
PPC_INS_QVFNEG = 441
PPC_INS_QVFNMADD = 442
PPC_INS_QVFNMADDS = 443
PPC_INS_QVFNMSUB = 444
PPC_INS_QVFNMSUBS = 445
PPC_INS_QVFPERM = 446
PPC_INS_QVFRE = 447
PPC_INS_QVFRES = 448
PPC_INS_QVFRIM = 449
PPC_INS_QVFRIN = 450
PPC_INS_QVFRIP = 451
PPC_INS_QVFRIZ = 452
PPC_INS_QVFRSP = 453
PPC_INS_QVFRSQRTE = 454
PPC_INS_QVFRSQRTES = 455
PPC_INS_QVFSEL = 456
PPC_INS_QVFSUB = 457
PPC_INS_QVFSUBS = 458
PPC_INS_QVFTSTNAN = 459
PPC_INS_QVFXMADD = 460
PPC_INS_QVFXMADDS = 461
PPC_INS_QVFXMUL = 462
PPC_INS_QVFXMULS = 463
PPC_INS_QVFXXCPNMADD = 464
PPC_INS_QVFXXCPNMADDS = 465
PPC_INS_QVFXXMADD = 466
PPC_INS_QVFXXMADDS = 467
PPC_INS_QVFXXNPMADD = 468
PPC_INS_QVFXXNPMADDS = 469
PPC_INS_QVGPCI = 470
PPC_INS_QVLFCDUX = 471
PPC_INS_QVLFCDUXA = 472
PPC_INS_QVLFCDX = 473
PPC_INS_QVLFCDXA = 474
PPC_INS_QVLFCSUX = 475
PPC_INS_QVLFCSUXA = 476
PPC_INS_QVLFCSX = 477
PPC_INS_QVLFCSXA = 478
PPC_INS_QVLFDUX = 479
PPC_INS_QVLFDUXA = 480
PPC_INS_QVLFDX = 481
PPC_INS_QVLFDXA = 482
PPC_INS_QVLFIWAX = 483
PPC_INS_QVLFIWAXA = 484
PPC_INS_QVLFIWZX = 485
PPC_INS_QVLFIWZXA = 486
PPC_INS_QVLFSUX = 487
PPC_INS_QVLFSUXA = 488
PPC_INS_QVLFSX = 489
PPC_INS_QVLFSXA = 490
PPC_INS_QVLPCLDX = 491
PPC_INS_QVLPCLSX = 492
PPC_INS_QVLPCRDX = 493
PPC_INS_QVLPCRSX = 494
PPC_INS_QVSTFCDUX = 495
PPC_INS_QVSTFCDUXA = 496
PPC_INS_QVSTFCDUXI = 497
PPC_INS_QVSTFCDUXIA = 498
PPC_INS_QVSTFCDX = 499
PPC_INS_QVSTFCDXA = 500
PPC_INS_QVSTFCDXI = 501
PPC_INS_QVSTFCDXIA = 502
PPC_INS_QVSTFCSUX = 503
PPC_INS_QVSTFCSUXA = 504
PPC_INS_QVSTFCSUXI = 505
PPC_INS_QVSTFCSUXIA = 506
PPC_INS_QVSTFCSX = 507
PPC_INS_QVSTFCSXA = 508
PPC_INS_QVSTFCSXI = 509
PPC_INS_QVSTFCSXIA = 510
PPC_INS_QVSTFDUX = 511
PPC_INS_QVSTFDUXA = 512
PPC_INS_QVSTFDUXI = 513
PPC_INS_QVSTFDUXIA = 514
PPC_INS_QVSTFDX = 515
PPC_INS_QVSTFDXA = 516
PPC_INS_QVSTFDXI = 517
PPC_INS_QVSTFDXIA = 518
PPC_INS_QVSTFIWX = 519
PPC_INS_QVSTFIWXA = 520
PPC_INS_QVSTFSUX = 521
PPC_INS_QVSTFSUXA = 522
PPC_INS_QVSTFSUXI = 523
PPC_INS_QVSTFSUXIA = 524
PPC_INS_QVSTFSX = 525
PPC_INS_QVSTFSXA = 526
PPC_INS_QVSTFSXI = 527
PPC_INS_QVSTFSXIA = 528
PPC_INS_RFCI = 529
PPC_INS_RFDI = 530
PPC_INS_RFI = 531
PPC_INS_RFID = 532
PPC_INS_RFMCI = 533
PPC_INS_RLDCL = 534
PPC_INS_RLDCR = 535
PPC_INS_RLDIC = 536
PPC_INS_RLDICL = 537
PPC_INS_RLDICR = 538
PPC_INS_RLDIMI = 539
PPC_INS_RLWIMI = 540
PPC_INS_RLWINM = 541
PPC_INS_RLWNM = 542
PPC_INS_SC = 543
PPC_INS_SLBIA = 544
PPC_INS_SLBIE = 545
PPC_INS_SLBMFEE = 546
PPC_INS_SLBMTE = 547
PPC_INS_SLD = 548
PPC_INS_SLW = 549
PPC_INS_SRAD = 550
PPC_INS_SRADI = 551
PPC_INS_SRAW = 552
PPC_INS_SRAWI = 553
PPC_INS_SRD = 554
PPC_INS_SRW = 555
PPC_INS_STB = 556
PPC_INS_STBCIX = 557
PPC_INS_STBU = 558
PPC_INS_STBUX = 559
PPC_INS_STBX = 560
PPC_INS_STD = 561
PPC_INS_STDBRX = 562
PPC_INS_STDCIX = 563
PPC_INS_STDCX = 564
PPC_INS_STDU = 565
PPC_INS_STDUX = 566
PPC_INS_STDX = 567
PPC_INS_STFD = 568
PPC_INS_STFDU = 569
PPC_INS_STFDUX = 570
PPC_INS_STFDX = 571
PPC_INS_STFIWX = 572
PPC_INS_STFS = 573
PPC_INS_STFSU = 574
PPC_INS_STFSUX = 575
PPC_INS_STFSX = 576
PPC_INS_STH = 577
PPC_INS_STHBRX = 578
PPC_INS_STHCIX = 579
PPC_INS_STHU = 580
PPC_INS_STHUX = 581
PPC_INS_STHX = 582
PPC_INS_STMW = 583
PPC_INS_STSWI = 584
PPC_INS_STVEBX = 585
PPC_INS_STVEHX = 586
PPC_INS_STVEWX = 587
PPC_INS_STVX = 588
PPC_INS_STVXL = 589
PPC_INS_STW = 590
PPC_INS_STWBRX = 591
PPC_INS_STWCIX = 592
PPC_INS_STWCX = 593
PPC_INS_STWU = 594
PPC_INS_STWUX = 595
PPC_INS_STWX = 596
PPC_INS_STXSDX = 597
PPC_INS_STXVD2X = 598
PPC_INS_STXVW4X = 599
PPC_INS_SUBF = 600
PPC_INS_SUBFC = 601
PPC_INS_SUBFE = 602
PPC_INS_SUBFIC = 603
PPC_INS_SUBFME = 604
PPC_INS_SUBFZE = 605
PPC_INS_SYNC = 606
PPC_INS_TD = 607
PPC_INS_TDI = 608
PPC_INS_TLBIA = 609
PPC_INS_TLBIE = 610
PPC_INS_TLBIEL = 611
PPC_INS_TLBIVAX = 612
PPC_INS_TLBLD = 613
PPC_INS_TLBLI = 614
PPC_INS_TLBRE = 615
PPC_INS_TLBSX = 616
PPC_INS_TLBSYNC = 617
PPC_INS_TLBWE = 618
PPC_INS_TRAP = 619
PPC_INS_TW = 620
PPC_INS_TWI = 621
PPC_INS_VADDCUW = 622
PPC_INS_VADDFP = 623
PPC_INS_VADDSBS = 624
PPC_INS_VADDSHS = 625
PPC_INS_VADDSWS = 626
PPC_INS_VADDUBM = 627
PPC_INS_VADDUBS = 628
PPC_INS_VADDUDM = 629
PPC_INS_VADDUHM = 630
PPC_INS_VADDUHS = 631
PPC_INS_VADDUWM = 632
PPC_INS_VADDUWS = 633
PPC_INS_VAND = 634
PPC_INS_VANDC = 635
PPC_INS_VAVGSB = 636
PPC_INS_VAVGSH = 637
PPC_INS_VAVGSW = 638
PPC_INS_VAVGUB = 639
PPC_INS_VAVGUH = 640
PPC_INS_VAVGUW = 641
PPC_INS_VCFSX = 642
PPC_INS_VCFUX = 643
PPC_INS_VCLZB = 644
PPC_INS_VCLZD = 645
PPC_INS_VCLZH = 646
PPC_INS_VCLZW = 647
PPC_INS_VCMPBFP = 648
PPC_INS_VCMPEQFP = 649
PPC_INS_VCMPEQUB = 650
PPC_INS_VCMPEQUD = 651
PPC_INS_VCMPEQUH = 652
PPC_INS_VCMPEQUW = 653
PPC_INS_VCMPGEFP = 654
PPC_INS_VCMPGTFP = 655
PPC_INS_VCMPGTSB = 656
PPC_INS_VCMPGTSD = 657
PPC_INS_VCMPGTSH = 658
PPC_INS_VCMPGTSW = 659
PPC_INS_VCMPGTUB = 660
PPC_INS_VCMPGTUD = 661
PPC_INS_VCMPGTUH = 662
PPC_INS_VCMPGTUW = 663
PPC_INS_VCTSXS = 664
PPC_INS_VCTUXS = 665
PPC_INS_VEQV = 666
PPC_INS_VEXPTEFP = 667
PPC_INS_VLOGEFP = 668
PPC_INS_VMADDFP = 669
PPC_INS_VMAXFP = 670
PPC_INS_VMAXSB = 671
PPC_INS_VMAXSD = 672
PPC_INS_VMAXSH = 673
PPC_INS_VMAXSW = 674
PPC_INS_VMAXUB = 675
PPC_INS_VMAXUD = 676
PPC_INS_VMAXUH = 677
PPC_INS_VMAXUW = 678
PPC_INS_VMHADDSHS = 679
PPC_INS_VMHRADDSHS = 680
PPC_INS_VMINUD = 681
PPC_INS_VMINFP = 682
PPC_INS_VMINSB = 683
PPC_INS_VMINSD = 684
PPC_INS_VMINSH = 685
PPC_INS_VMINSW = 686
PPC_INS_VMINUB = 687
PPC_INS_VMINUH = 688
PPC_INS_VMINUW = 689
PPC_INS_VMLADDUHM = 690
PPC_INS_VMRGHB = 691
PPC_INS_VMRGHH = 692
PPC_INS_VMRGHW = 693
PPC_INS_VMRGLB = 694
PPC_INS_VMRGLH = 695
PPC_INS_VMRGLW = 696
PPC_INS_VMSUMMBM = 697
PPC_INS_VMSUMSHM = 698
PPC_INS_VMSUMSHS = 699
PPC_INS_VMSUMUBM = 700
PPC_INS_VMSUMUHM = 701
PPC_INS_VMSUMUHS = 702
PPC_INS_VMULESB = 703
PPC_INS_VMULESH = 704
PPC_INS_VMULESW = 705
PPC_INS_VMULEUB = 706
PPC_INS_VMULEUH = 707
PPC_INS_VMULEUW = 708
PPC_INS_VMULOSB = 709
PPC_INS_VMULOSH = 710
PPC_INS_VMULOSW = 711
PPC_INS_VMULOUB = 712
PPC_INS_VMULOUH = 713
PPC_INS_VMULOUW = 714
PPC_INS_VMULUWM = 715
PPC_INS_VNAND = 716
PPC_INS_VNMSUBFP = 717
PPC_INS_VNOR = 718
PPC_INS_VOR = 719
PPC_INS_VORC = 720
PPC_INS_VPERM = 721
PPC_INS_VPKPX = 722
PPC_INS_VPKSHSS = 723
PPC_INS_VPKSHUS = 724
PPC_INS_VPKSWSS = 725
PPC_INS_VPKSWUS = 726
PPC_INS_VPKUHUM = 727
PPC_INS_VPKUHUS = 728
PPC_INS_VPKUWUM = 729
PPC_INS_VPKUWUS = 730
PPC_INS_VPOPCNTB = 731
PPC_INS_VPOPCNTD = 732
PPC_INS_VPOPCNTH = 733
PPC_INS_VPOPCNTW = 734
PPC_INS_VREFP = 735
PPC_INS_VRFIM = 736
PPC_INS_VRFIN = 737
PPC_INS_VRFIP = 738
PPC_INS_VRFIZ = 739
PPC_INS_VRLB = 740
PPC_INS_VRLD = 741
PPC_INS_VRLH = 742
PPC_INS_VRLW = 743
PPC_INS_VRSQRTEFP = 744
PPC_INS_VSEL = 745
PPC_INS_VSL = 746
PPC_INS_VSLB = 747
PPC_INS_VSLD = 748
PPC_INS_VSLDOI = 749
PPC_INS_VSLH = 750
PPC_INS_VSLO = 751
PPC_INS_VSLW = 752
PPC_INS_VSPLTB = 753
PPC_INS_VSPLTH = 754
PPC_INS_VSPLTISB = 755
PPC_INS_VSPLTISH = 756
PPC_INS_VSPLTISW = 757
PPC_INS_VSPLTW = 758
PPC_INS_VSR = 759
PPC_INS_VSRAB = 760
PPC_INS_VSRAD = 761
PPC_INS_VSRAH = 762
PPC_INS_VSRAW = 763
PPC_INS_VSRB = 764
PPC_INS_VSRD = 765
PPC_INS_VSRH = 766
PPC_INS_VSRO = 767
PPC_INS_VSRW = 768
PPC_INS_VSUBCUW = 769
PPC_INS_VSUBFP = 770
PPC_INS_VSUBSBS = 771
PPC_INS_VSUBSHS = 772
PPC_INS_VSUBSWS = 773
PPC_INS_VSUBUBM = 774
PPC_INS_VSUBUBS = 775
PPC_INS_VSUBUDM = 776
PPC_INS_VSUBUHM = 777
PPC_INS_VSUBUHS = 778
PPC_INS_VSUBUWM = 779
PPC_INS_VSUBUWS = 780
PPC_INS_VSUM2SWS = 781
PPC_INS_VSUM4SBS = 782
PPC_INS_VSUM4SHS = 783
PPC_INS_VSUM4UBS = 784
PPC_INS_VSUMSWS = 785
PPC_INS_VUPKHPX = 786
PPC_INS_VUPKHSB = 787
PPC_INS_VUPKHSH = 788
PPC_INS_VUPKLPX = 789
PPC_INS_VUPKLSB = 790
PPC_INS_VUPKLSH = 791
PPC_INS_VXOR = 792
PPC_INS_WAIT = 793
PPC_INS_WRTEE = 794
PPC_INS_WRTEEI = 795
PPC_INS_XOR = 796
PPC_INS_XORI = 797
PPC_INS_XORIS = 798
PPC_INS_XSABSDP = 799
PPC_INS_XSADDDP = 800
PPC_INS_XSCMPODP = 801
PPC_INS_XSCMPUDP = 802
PPC_INS_XSCPSGNDP = 803
PPC_INS_XSCVDPSP = 804
PPC_INS_XSCVDPSXDS = 805
PPC_INS_XSCVDPSXWS = 806
PPC_INS_XSCVDPUXDS = 807
PPC_INS_XSCVDPUXWS = 808
PPC_INS_XSCVSPDP = 809
PPC_INS_XSCVSXDDP = 810
PPC_INS_XSCVUXDDP = 811
PPC_INS_XSDIVDP = 812
PPC_INS_XSMADDADP = 813
PPC_INS_XSMADDMDP = 814
PPC_INS_XSMAXDP = 815
PPC_INS_XSMINDP = 816
PPC_INS_XSMSUBADP = 817
PPC_INS_XSMSUBMDP = 818
PPC_INS_XSMULDP = 819
PPC_INS_XSNABSDP = 820
PPC_INS_XSNEGDP = 821
PPC_INS_XSNMADDADP = 822
PPC_INS_XSNMADDMDP = 823
PPC_INS_XSNMSUBADP = 824
PPC_INS_XSNMSUBMDP = 825
PPC_INS_XSRDPI = 826
PPC_INS_XSRDPIC = 827
PPC_INS_XSRDPIM = 828
PPC_INS_XSRDPIP = 829
PPC_INS_XSRDPIZ = 830
PPC_INS_XSREDP = 831
PPC_INS_XSRSQRTEDP = 832
PPC_INS_XSSQRTDP = 833
PPC_INS_XSSUBDP = 834
PPC_INS_XSTDIVDP = 835
PPC_INS_XSTSQRTDP = 836
PPC_INS_XVABSDP = 837
PPC_INS_XVABSSP = 838
PPC_INS_XVADDDP = 839
PPC_INS_XVADDSP = 840
PPC_INS_XVCMPEQDP = 841
PPC_INS_XVCMPEQSP = 842
PPC_INS_XVCMPGEDP = 843
PPC_INS_XVCMPGESP = 844
PPC_INS_XVCMPGTDP = 845
PPC_INS_XVCMPGTSP = 846
PPC_INS_XVCPSGNDP = 847
PPC_INS_XVCPSGNSP = 848
PPC_INS_XVCVDPSP = 849
PPC_INS_XVCVDPSXDS = 850
PPC_INS_XVCVDPSXWS = 851
PPC_INS_XVCVDPUXDS = 852
PPC_INS_XVCVDPUXWS = 853
PPC_INS_XVCVSPDP = 854
PPC_INS_XVCVSPSXDS = 855
PPC_INS_XVCVSPSXWS = 856
PPC_INS_XVCVSPUXDS = 857
PPC_INS_XVCVSPUXWS = 858
PPC_INS_XVCVSXDDP = 859
PPC_INS_XVCVSXDSP = 860
PPC_INS_XVCVSXWDP = 861
PPC_INS_XVCVSXWSP = 862
PPC_INS_XVCVUXDDP = 863
PPC_INS_XVCVUXDSP = 864
PPC_INS_XVCVUXWDP = 865
PPC_INS_XVCVUXWSP = 866
PPC_INS_XVDIVDP = 867
PPC_INS_XVDIVSP = 868
PPC_INS_XVMADDADP = 869
PPC_INS_XVMADDASP = 870
PPC_INS_XVMADDMDP = 871
PPC_INS_XVMADDMSP = 872
PPC_INS_XVMAXDP = 873
PPC_INS_XVMAXSP = 874
PPC_INS_XVMINDP = 875
PPC_INS_XVMINSP = 876
PPC_INS_XVMSUBADP = 877
PPC_INS_XVMSUBASP = 878
PPC_INS_XVMSUBMDP = 879
PPC_INS_XVMSUBMSP = 880
PPC_INS_XVMULDP = 881
PPC_INS_XVMULSP = 882
PPC_INS_XVNABSDP = 883
PPC_INS_XVNABSSP = 884
PPC_INS_XVNEGDP = 885
PPC_INS_XVNEGSP = 886
PPC_INS_XVNMADDADP = 887
PPC_INS_XVNMADDASP = 888
PPC_INS_XVNMADDMDP = 889
PPC_INS_XVNMADDMSP = 890
PPC_INS_XVNMSUBADP = 891
PPC_INS_XVNMSUBASP = 892
PPC_INS_XVNMSUBMDP = 893
PPC_INS_XVNMSUBMSP = 894
PPC_INS_XVRDPI = 895
PPC_INS_XVRDPIC = 896
PPC_INS_XVRDPIM = 897
PPC_INS_XVRDPIP = 898
PPC_INS_XVRDPIZ = 899
PPC_INS_XVREDP = 900
PPC_INS_XVRESP = 901
PPC_INS_XVRSPI = 902
PPC_INS_XVRSPIC = 903
PPC_INS_XVRSPIM = 904
PPC_INS_XVRSPIP = 905
PPC_INS_XVRSPIZ = 906
PPC_INS_XVRSQRTEDP = 907
PPC_INS_XVRSQRTESP = 908
PPC_INS_XVSQRTDP = 909
PPC_INS_XVSQRTSP = 910
PPC_INS_XVSUBDP = 911
PPC_INS_XVSUBSP = 912
PPC_INS_XVTDIVDP = 913
PPC_INS_XVTDIVSP = 914
PPC_INS_XVTSQRTDP = 915
PPC_INS_XVTSQRTSP = 916
PPC_INS_XXLAND = 917
PPC_INS_XXLANDC = 918
PPC_INS_XXLEQV = 919
PPC_INS_XXLNAND = 920
PPC_INS_XXLNOR = 921
PPC_INS_XXLOR = 922
PPC_INS_XXLORC = 923
PPC_INS_XXLXOR = 924
PPC_INS_XXMRGHW = 925
PPC_INS_XXMRGLW = 926
PPC_INS_XXPERMDI = 927
PPC_INS_XXSEL = 928
PPC_INS_XXSLDWI = 929
PPC_INS_XXSPLTW = 930
PPC_INS_BCA = 931
PPC_INS_BCLA = 932
PPC_INS_SLWI = 933
PPC_INS_SRWI = 934
PPC_INS_SLDI = 935
PPC_INS_BTA = 936
PPC_INS_CRSET = 937
PPC_INS_CRNOT = 938
PPC_INS_CRMOVE = 939
PPC_INS_CRCLR = 940
PPC_INS_MFBR0 = 941
PPC_INS_MFBR1 = 942
PPC_INS_MFBR2 = 943
PPC_INS_MFBR3 = 944
PPC_INS_MFBR4 = 945
PPC_INS_MFBR5 = 946
PPC_INS_MFBR6 = 947
PPC_INS_MFBR7 = 948
PPC_INS_MFXER = 949
PPC_INS_MFRTCU = 950
PPC_INS_MFRTCL = 951
PPC_INS_MFDSCR = 952
PPC_INS_MFDSISR = 953
PPC_INS_MFDAR = 954
PPC_INS_MFSRR2 = 955
PPC_INS_MFSRR3 = 956
PPC_INS_MFCFAR = 957
PPC_INS_MFAMR = 958
PPC_INS_MFPID = 959
PPC_INS_MFTBLO = 960
PPC_INS_MFTBHI = 961
PPC_INS_MFDBATU = 962
PPC_INS_MFDBATL = 963
PPC_INS_MFIBATU = 964
PPC_INS_MFIBATL = 965
PPC_INS_MFDCCR = 966
PPC_INS_MFICCR = 967
PPC_INS_MFDEAR = 968
PPC_INS_MFESR = 969
PPC_INS_MFSPEFSCR = 970
PPC_INS_MFTCR = 971
PPC_INS_MFASR = 972
PPC_INS_MFPVR = 973
PPC_INS_MFTBU = 974
PPC_INS_MTCR = 975
PPC_INS_MTBR0 = 976
PPC_INS_MTBR1 = 977
PPC_INS_MTBR2 = 978
PPC_INS_MTBR3 = 979
PPC_INS_MTBR4 = 980
PPC_INS_MTBR5 = 981
PPC_INS_MTBR6 = 982
PPC_INS_MTBR7 = 983
PPC_INS_MTXER = 984
PPC_INS_MTDSCR = 985
PPC_INS_MTDSISR = 986
PPC_INS_MTDAR = 987
PPC_INS_MTSRR2 = 988
PPC_INS_MTSRR3 = 989
PPC_INS_MTCFAR = 990
PPC_INS_MTAMR = 991
PPC_INS_MTPID = 992
PPC_INS_MTTBL = 993
PPC_INS_MTTBU = 994
PPC_INS_MTTBLO = 995
PPC_INS_MTTBHI = 996
PPC_INS_MTDBATU = 997
PPC_INS_MTDBATL = 998
PPC_INS_MTIBATU = 999
PPC_INS_MTIBATL = 1000
PPC_INS_MTDCCR = 1001
PPC_INS_MTICCR = 1002
PPC_INS_MTDEAR = 1003
PPC_INS_MTESR = 1004
PPC_INS_MTSPEFSCR = 1005
PPC_INS_MTTCR = 1006
PPC_INS_NOT = 1007
PPC_INS_MR = 1008
PPC_INS_ROTLD = 1009
PPC_INS_ROTLDI = 1010
PPC_INS_CLRLDI = 1011
PPC_INS_ROTLWI = 1012
PPC_INS_CLRLWI = 1013
PPC_INS_ROTLW = 1014
PPC_INS_SUB = 1015
PPC_INS_SUBC = 1016
PPC_INS_LWSYNC = 1017
PPC_INS_PTESYNC = 1018
PPC_INS_TDLT = 1019
PPC_INS_TDEQ = 1020
PPC_INS_TDGT = 1021
PPC_INS_TDNE = 1022
PPC_INS_TDLLT = 1023
PPC_INS_TDLGT = 1024
PPC_INS_TDU = 1025
PPC_INS_TDLTI = 1026
PPC_INS_TDEQI = 1027
PPC_INS_TDGTI = 1028
PPC_INS_TDNEI = 1029
PPC_INS_TDLLTI = 1030
PPC_INS_TDLGTI = 1031
PPC_INS_TDUI = 1032
PPC_INS_TLBREHI = 1033
PPC_INS_TLBRELO = 1034
PPC_INS_TLBWEHI = 1035
PPC_INS_TLBWELO = 1036
PPC_INS_TWLT = 1037
PPC_INS_TWEQ = 1038
PPC_INS_TWGT = 1039
PPC_INS_TWNE = 1040
PPC_INS_TWLLT = 1041
PPC_INS_TWLGT = 1042
PPC_INS_TWU = 1043
PPC_INS_TWLTI = 1044
PPC_INS_TWEQI = 1045
PPC_INS_TWGTI = 1046
PPC_INS_TWNEI = 1047
PPC_INS_TWLLTI = 1048
PPC_INS_TWLGTI = 1049
PPC_INS_TWUI = 1050
PPC_INS_WAITRSV = 1051
PPC_INS_WAITIMPL = 1052
PPC_INS_XNOP = 1053
PPC_INS_XVMOVDP = 1054
PPC_INS_XVMOVSP = 1055
PPC_INS_XXSPLTD = 1056
PPC_INS_XXMRGHD = 1057
PPC_INS_XXMRGLD = 1058
PPC_INS_XXSWAPD = 1059
PPC_INS_BT = 1060
PPC_INS_BF = 1061
PPC_INS_BDNZT = 1062
PPC_INS_BDNZF = 1063
PPC_INS_BDZF = 1064
PPC_INS_BDZT = 1065
PPC_INS_BFA = 1066
PPC_INS_BDNZTA = 1067
PPC_INS_BDNZFA = 1068
PPC_INS_BDZTA = 1069
PPC_INS_BDZFA = 1070
PPC_INS_BTCTR = 1071
PPC_INS_BFCTR = 1072
PPC_INS_BTCTRL = 1073
PPC_INS_BFCTRL = 1074
PPC_INS_BTL = 1075
PPC_INS_BFL = 1076
PPC_INS_BDNZTL = 1077
PPC_INS_BDNZFL = 1078
PPC_INS_BDZTL = 1079
PPC_INS_BDZFL = 1080
PPC_INS_BTLA = 1081
PPC_INS_BFLA = 1082
PPC_INS_BDNZTLA = 1083
PPC_INS_BDNZFLA = 1084
PPC_INS_BDZTLA = 1085
PPC_INS_BDZFLA = 1086
PPC_INS_BTLR = 1087
PPC_INS_BFLR = 1088
PPC_INS_BDNZTLR = 1089
PPC_INS_BDZTLR = 1090
PPC_INS_BDZFLR = 1091
PPC_INS_BTLRL = 1092
PPC_INS_BFLRL = 1093
PPC_INS_BDNZTLRL = 1094
PPC_INS_BDNZFLRL = 1095
PPC_INS_BDZTLRL = 1096
PPC_INS_BDZFLRL = 1097
PPC_INS_QVFAND = 1098
PPC_INS_QVFCLR = 1099
PPC_INS_QVFANDC = 1100
PPC_INS_QVFCTFB = 1101
PPC_INS_QVFXOR = 1102
PPC_INS_QVFOR = 1103
PPC_INS_QVFNOR = 1104
PPC_INS_QVFEQU = 1105
PPC_INS_QVFNOT = 1106
PPC_INS_QVFORC = 1107
PPC_INS_QVFNAND = 1108
PPC_INS_QVFSET = 1109
PPC_INS_ENDING = 1110

PPC_GRP_INVALID = 0
PPC_GRP_JUMP = 1
PPC_GRP_ALTIVEC = 128
PPC_GRP_MODE32 = 129
PPC_GRP_MODE64 = 130
PPC_GRP_BOOKE = 131
PPC_GRP_NOTBOOKE = 132
PPC_GRP_SPE = 133
PPC_GRP_VSX = 134
PPC_GRP_E500 = 135
PPC_GRP_PPC4XX = 136
PPC_GRP_PPC6XX = 137
PPC_GRP_ICBT = 138
PPC_GRP_P8ALTIVEC = 139
PPC_GRP_P8VECTOR = 140
PPC_GRP_QPX = 141
PPC_GRP_ENDING = 142



# By Dang Hoang Vu <danghvu@gmail.com>, 2014

from libcpp cimport bool
from libc.stdint cimport uint8_t, uint64_t, uint16_t

cdef extern from "<capstone/capstone.h>":

    ctypedef size_t csh

    ctypedef enum cs_mode:
        pass

    ctypedef enum cs_arch:
        pass

    ctypedef struct cs_detail:
        pass

    ctypedef struct cs_insn:
        unsigned int id
        uint64_t address
        uint16_t size
        uint8_t bytes[16]
        char mnemonic[32]
        char op_str[160]
        cs_detail *detail

    ctypedef enum cs_err:
        pass

    ctypedef enum cs_opt_type:
        pass

    unsigned int cs_version(int *major, int *minor)

    bool cs_support(int arch)

    cs_err cs_open(cs_arch arch, cs_mode mode, csh *handle)

    cs_err cs_close(csh *handle)

    cs_err cs_errno(csh handle)

    size_t cs_disasm(csh handle,
        const uint8_t *code, size_t code_size,
        uint64_t address,
        size_t count,
        cs_insn **insn)

    cs_err cs_option(csh handle, cs_opt_type type, size_t value)

    void cs_free(cs_insn *insn, size_t count)

    const char *cs_reg_name(csh handle, unsigned int reg_id)

    const char *cs_insn_name(csh handle, unsigned int insn_id)

    const char *cs_group_name(csh handle, unsigned int group_id)

    bool cs_insn_group(csh handle, cs_insn *insn, unsigned int group_id)

    bool cs_reg_read(csh handle, cs_insn *insn, unsigned int reg_id)

    bool cs_reg_write(csh handle, cs_insn *insn, unsigned int reg_id)

    int cs_op_count(csh handle, cs_insn *insn, unsigned int op_type)

    cs_err cs_regs_access(csh handle, cs_insn *insn, uint16_t *regs_read, uint8_t *read_count, uint16_t *regs_write, uint8_t *write_count)

    int cs_op_index(csh handle, cs_insn *insn, unsigned int op_type,
        unsigned int position)




# Capstone Disassembler Engine
# By Dang Hoang Vu, 2013
from __future__ import print_function
import sys, re

INCL_DIR = '../include/capstone/'

include = [ 'arm.h', 'arm64.h', 'm68k.h', 'mips.h', 'x86.h', 'ppc.h', 'sparc.h', 'systemz.h', 'xcore.h', 'tms320c64x.h', 'm680x.h', 'evm.h' ]

template = {
    'java': {
            'header': "// For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT\npackage capstone;\n\npublic class %s_const {\n",
            'footer': "}",
            'line_format': '\tpublic static final int %s = %s;\n',
            'out_file': './java/capstone/%s_const.java',
            # prefixes for constant filenames of all archs - case sensitive
            'arm.h': 'Arm',
            'arm64.h': 'Arm64',
            'm68k.h': 'M68k',
            'mips.h': 'Mips',
            'x86.h': 'X86',
            'ppc.h': 'Ppc',
            'sparc.h': 'Sparc',
            'systemz.h': 'Sysz',
            'xcore.h': 'Xcore',
            'tms320c64x.h': 'TMS320C64x',
            'm680x.h': 'M680x',
            'evm.h': 'Evm',
            'comment_open': '\t//',
            'comment_close': '',
        },
    'python': {
            'header': "# For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [%s_const.py]\n",
            'footer': "",
            'line_format': '%s = %s\n',
            'out_file': './python/capstone/%s_const.py',
            # prefixes for constant filenames of all archs - case sensitive
            'arm.h': 'arm',
            'arm64.h': 'arm64',
            'm68k.h': 'm68k',
            'mips.h': 'mips',
            'x86.h': 'x86',
            'ppc.h': 'ppc',
            'sparc.h': 'sparc',
            'systemz.h': 'sysz',
            'xcore.h': 'xcore',
            'tms320c64x.h': 'tms320c64x',
            'm680x.h': 'm680x',
            'evm.h': 'evm',
            'comment_open': '#',
            'comment_close': '',
        },
    'ocaml': {
            'header': "(* For Capstone Engine. AUTO-GENERATED FILE, DO NOT EDIT [%s_const.ml] *)\n",
            'footer': "",
            'line_format': 'let _%s = %s;;\n',
            'out_file': './ocaml/%s_const.ml',
            # prefixes for constant filenames of all archs - case sensitive
            'arm.h': 'arm',
            'arm64.h': 'arm64',
            'mips.h': 'mips',
            'm68k.h': 'm68k',
            'x86.h': 'x86',
            'ppc.h': 'ppc',
            'sparc.h': 'sparc',
            'systemz.h': 'sysz',
            'xcore.h': 'xcore',
            'tms320c64x.h': 'tms320c64x',
            'm680x.h': 'm680x',
            'evm.h': 'evm',
            'comment_open': '(*',
            'comment_close': ' *)',
        },
}

# markup for comments to be added to autogen files
MARKUP = '//>'

def gen(lang):
    global include, INCL_DIR
    print('Generating bindings for', lang)
    templ = template[lang]
    print('Generating bindings for', lang)
    for target in include:
        prefix = templ[target]
        outfile = open(templ['out_file'] %(prefix), 'wb')   # open as binary prevents windows newlines
        outfile.write((templ['header'] % (prefix)).encode("utf-8"))

        lines = open(INCL_DIR + target).readlines()

        count = 0
        for line in lines:
            line = line.strip()

            if line.startswith(MARKUP):  # markup for comments
                outfile.write(("\n%s%s%s\n" %(templ['comment_open'], \
                                              line.replace(MARKUP, ''), \
                                              templ['comment_close']) ).encode("utf-8"))
                continue

            if line == '' or line.startswith('//'):
                continue

            if line.startswith('#define '):
                line = line[8:]     #cut off define
                xline = re.split('\s+', line, 1)     #split to at most 2 express
                if len(xline) != 2:
                    continue
                if '(' in xline[0] or ')' in xline[0]:      #does it look like a function
                    continue
                xline.insert(1, '=')            # insert an = so the expression below can parse it
                line = ' '.join(xline)

            if not line.startswith(prefix.upper()):
                continue

            tmp = line.strip().split(',')
            for t in tmp:
                t = t.strip()
                if not t or t.startswith('//'): continue
                # hacky: remove type cast (uint64_t)
                t = t.replace('(uint64_t)', '')
                t = re.sub(r'\((\d+)ULL << (\d+)\)', r'\1 << \2', t)    # (1ULL<<1) to 1 << 1
                f = re.split('\s+', t)

                if f[0].startswith(prefix.upper()):
                    if len(f) > 1 and f[1] not in ('//', '///<', '='):
                        print("Error: Unable to convert %s" % f)
                        continue
                    elif len(f) > 1 and f[1] == '=':
                        rhs = ''.join(f[2:])
                    else:
                        rhs = str(count)
                        count += 1

                    try:
                        count = int(rhs) + 1
                        if (count == 1):
                            outfile.write(("\n").encode("utf-8"))
                    except ValueError:
                        if lang == 'ocaml':
                            # ocaml uses lsl for '<<', lor for '|'
                            rhs = rhs.replace('<<', ' lsl ')
                            rhs = rhs.replace('|', ' lor ')
                            # ocaml variable has _ as prefix
                            if rhs[0].isalpha():
                                rhs = '_' + rhs

                    outfile.write((templ['line_format'] %(f[0].strip(), rhs)).encode("utf-8"))

        outfile.write((templ['footer']).encode("utf-8"))
        outfile.close()

def main():
    try:
        if sys.argv[1] == 'all':
            for key in template.keys():
                gen(key)
        else:
            gen(sys.argv[1])
    except:
        raise RuntimeError("Unsupported binding %s" % sys.argv[1])

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Usage:", sys.argv[0], " <bindings: java|python|ocaml|all>")
        sys.exit(1)
    main()
